%%
%% %CopyrightBegin%
%%
%% Copyright Ericsson AB 2008-2023. All Rights Reserved.
%%
%% Licensed under the Apache License, Version 2.0 (the "License");
%% you may not use this file except in compliance with the License.
%% You may obtain a copy of the License at
%%
%%     http://www.apache.org/licenses/LICENSE-2.0
%%
%% Unless required by applicable law or agreed to in writing, software
%% distributed under the License is distributed on an "AS IS" BASIS,
%% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
%% See the License for the specific language governing permissions and
%% limitations under the License.
%%
%% %CopyrightEnd%
%% This file is generated DO NOT EDIT

%% We define each id so we don't get huge diffs when adding new funcs/classes

-define(wxEvtHandler_Connect, 100).
-define(wxEvtHandler_Disconnect_2, 101).
-define(wxEvtHandler_Disconnect_1, 102).
-define(wxEvtHandler_Disconnect_0, 103).
-define(wxWindow_new_0, 104).
-define(wxWindow_new_3, 105).
-define(wxWindow_destruct, 106).
-define(wxWindow_Create, 107).
-define(wxWindow_CacheBestSize, 108).
-define(wxWindow_CaptureMouse, 109).
-define(wxWindow_Centre, 110).
-define(wxWindow_CentreOnParent, 111).
-define(wxWindow_ClearBackground, 112).
-define(wxWindow_ClientToScreen_2, 113).
-define(wxWindow_ClientToScreen_1, 114).
-define(wxWindow_Close, 115).
-define(wxWindow_ConvertDialogToPixels, 117).
-define(wxWindow_ConvertPixelsToDialog, 119).
-define(wxWindow_Destroy, 120).
-define(wxWindow_DestroyChildren, 121).
-define(wxWindow_Disable, 122).
-define(wxWindow_DragAcceptFiles, 123).
-define(wxWindow_Enable, 124).
-define(wxWindow_FindFocus, 125).
-define(wxWindow_FindWindow_1_0, 126).
-define(wxWindow_FindWindow_1_1, 127).
-define(wxWindow_FindWindowById, 128).
-define(wxWindow_FindWindowByName, 129).
-define(wxWindow_FindWindowByLabel, 130).
-define(wxWindow_Fit, 131).
-define(wxWindow_FitInside, 132).
-define(wxWindow_Freeze, 133).
-define(wxWindow_GetAcceleratorTable, 134).
-define(wxWindow_GetBackgroundColour, 135).
-define(wxWindow_GetBackgroundStyle, 136).
-define(wxWindow_GetBestSize, 137).
-define(wxWindow_GetCaret, 138).
-define(wxWindow_GetCapture, 139).
-define(wxWindow_GetCharHeight, 140).
-define(wxWindow_GetCharWidth, 141).
-define(wxWindow_GetChildren, 143).
-define(wxWindow_GetClientSize, 145).
-define(wxWindow_GetContainingSizer, 146).
-define(wxWindow_GetCursor, 147).
-define(wxWindow_GetDropTarget, 148).
-define(wxWindow_GetDPIScaleFactor, 149).
-define(wxWindow_GetExtraStyle, 150).
-define(wxWindow_GetFont, 151).
-define(wxWindow_GetForegroundColour, 152).
-define(wxWindow_GetGrandParent, 153).
-define(wxWindow_GetHandle, 154).
-define(wxWindow_GetHelpText, 155).
-define(wxWindow_GetId, 156).
-define(wxWindow_GetLabel, 157).
-define(wxWindow_GetMaxSize, 158).
-define(wxWindow_GetMinSize, 159).
-define(wxWindow_GetName, 160).
-define(wxWindow_GetParent, 161).
-define(wxWindow_GetPosition, 163).
-define(wxWindow_GetRect, 164).
-define(wxWindow_GetScreenPosition, 166).
-define(wxWindow_GetScreenRect, 167).
-define(wxWindow_GetScrollPos, 168).
-define(wxWindow_GetScrollRange, 169).
-define(wxWindow_GetScrollThumb, 170).
-define(wxWindow_GetSize, 172).
-define(wxWindow_GetSizer, 173).
-define(wxWindow_GetTextExtent, 174).
-define(wxWindow_GetThemeEnabled, 175).
-define(wxWindow_GetToolTip, 176).
-define(wxWindow_GetUpdateRegion, 177).
-define(wxWindow_GetVirtualSize, 178).
-define(wxWindow_GetWindowStyleFlag, 180).
-define(wxWindow_GetWindowVariant, 181).
-define(wxWindow_HasCapture, 182).
-define(wxWindow_HasScrollbar, 183).
-define(wxWindow_HasTransparentBackground, 184).
-define(wxWindow_Hide, 185).
-define(wxWindow_InheritAttributes, 186).
-define(wxWindow_InitDialog, 187).
-define(wxWindow_InvalidateBestSize, 188).
-define(wxWindow_IsFrozen, 189).
-define(wxWindow_IsEnabled, 190).
-define(wxWindow_IsExposed_2, 191).
-define(wxWindow_IsExposed_1_0, 192).
-define(wxWindow_IsExposed_4, 193).
-define(wxWindow_IsExposed_1_1, 194).
-define(wxWindow_IsRetained, 195).
-define(wxWindow_IsShown, 196).
-define(wxWindow_IsTopLevel, 197).
-define(wxWindow_IsShownOnScreen, 198).
-define(wxWindow_Layout, 199).
-define(wxWindow_LineDown, 200).
-define(wxWindow_LineUp, 201).
-define(wxWindow_Lower, 202).
-define(wxWindow_Move_3, 203).
-define(wxWindow_Move_2, 204).
-define(wxWindow_MoveAfterInTabOrder, 205).
-define(wxWindow_MoveBeforeInTabOrder, 206).
-define(wxWindow_Navigate, 207).
-define(wxWindow_PageDown, 208).
-define(wxWindow_PageUp, 209).
-define(wxWindow_PopupMenu_2, 210).
-define(wxWindow_PopupMenu_3, 211).
-define(wxWindow_Raise, 212).
-define(wxWindow_Refresh, 213).
-define(wxWindow_RefreshRect, 214).
-define(wxWindow_ReleaseMouse, 215).
-define(wxWindow_RemoveChild, 216).
-define(wxWindow_Reparent, 217).
-define(wxWindow_ScreenToClient_2, 218).
-define(wxWindow_ScreenToClient_1, 219).
-define(wxWindow_ScrollLines, 220).
-define(wxWindow_ScrollPages, 221).
-define(wxWindow_ScrollWindow, 222).
-define(wxWindow_SetAcceleratorTable, 223).
-define(wxWindow_SetAutoLayout, 224).
-define(wxWindow_SetBackgroundColour, 225).
-define(wxWindow_SetBackgroundStyle, 226).
-define(wxWindow_SetCaret, 227).
-define(wxWindow_SetClientSize_2, 228).
-define(wxWindow_SetClientSize_1_0, 229).
-define(wxWindow_SetClientSize_1_1, 230).
-define(wxWindow_SetContainingSizer, 231).
-define(wxWindow_SetCursor, 232).
-define(wxWindow_SetMaxSize, 233).
-define(wxWindow_SetMinSize, 234).
-define(wxWindow_SetOwnBackgroundColour, 235).
-define(wxWindow_SetOwnFont, 236).
-define(wxWindow_SetOwnForegroundColour, 237).
-define(wxWindow_SetDropTarget, 238).
-define(wxWindow_SetExtraStyle, 239).
-define(wxWindow_SetFocus, 240).
-define(wxWindow_SetFocusFromKbd, 241).
-define(wxWindow_SetFont, 242).
-define(wxWindow_SetForegroundColour, 243).
-define(wxWindow_SetHelpText, 244).
-define(wxWindow_SetId, 245).
-define(wxWindow_SetLabel, 246).
-define(wxWindow_SetName, 247).
-define(wxWindow_SetPalette, 248).
-define(wxWindow_SetScrollbar, 249).
-define(wxWindow_SetScrollPos, 250).
-define(wxWindow_SetSize_5, 251).
-define(wxWindow_SetSize_2_1, 252).
-define(wxWindow_SetSize_1, 253).
-define(wxWindow_SetSize_2_0, 254).
-define(wxWindow_SetSizeHints_2, 255).
-define(wxWindow_SetSizeHints_3, 256).
-define(wxWindow_SetSizer, 257).
-define(wxWindow_SetSizerAndFit, 258).
-define(wxWindow_SetThemeEnabled, 259).
-define(wxWindow_SetToolTip_1_0, 260).
-define(wxWindow_SetToolTip_1_1, 261).
-define(wxWindow_SetVirtualSize_2, 262).
-define(wxWindow_SetVirtualSize_1, 263).
-define(wxWindow_SetWindowStyle, 264).
-define(wxWindow_SetWindowStyleFlag, 265).
-define(wxWindow_SetWindowVariant, 266).
-define(wxWindow_ShouldInheritColours, 267).
-define(wxWindow_Show, 268).
-define(wxWindow_Thaw, 269).
-define(wxWindow_TransferDataFromWindow, 270).
-define(wxWindow_TransferDataToWindow, 271).
-define(wxWindow_Update, 272).
-define(wxWindow_UpdateWindowUI, 273).
-define(wxWindow_Validate, 274).
-define(wxWindow_WarpPointer, 275).
-define(wxWindow_SetTransparent, 276).
-define(wxWindow_CanSetTransparent, 277).
-define(wxWindow_IsDoubleBuffered, 278).
-define(wxWindow_SetDoubleBuffered, 279).
-define(wxWindow_GetContentScaleFactor, 280).
-define(wxWindow_GetDPI, 281).
-define(wxWindow_FromDIP_1_1, 282).
-define(wxWindow_FromDIP_1_0, 284).
-define(wxWindow_FromDIP_2_1, 285).
-define(wxWindow_FromDIP_2_0, 287).
-define(wxWindow_ToDIP_1_1, 288).
-define(wxWindow_ToDIP_1_0, 290).
-define(wxWindow_ToDIP_2_1, 291).
-define(wxWindow_ToDIP_2_0, 293).
-define(wxTopLevelWindow_GetIcon, 294).
-define(wxTopLevelWindow_GetIcons, 295).
-define(wxTopLevelWindow_GetTitle, 296).
-define(wxTopLevelWindow_IsActive, 297).
-define(wxTopLevelWindow_Iconize, 298).
-define(wxTopLevelWindow_IsFullScreen, 299).
-define(wxTopLevelWindow_IsIconized, 300).
-define(wxTopLevelWindow_IsMaximized, 301).
-define(wxTopLevelWindow_Maximize, 302).
-define(wxTopLevelWindow_RequestUserAttention, 303).
-define(wxTopLevelWindow_SetIcon, 304).
-define(wxTopLevelWindow_SetIcons, 305).
-define(wxTopLevelWindow_CentreOnScreen, 306).
-define(wxTopLevelWindow_SetShape, 307).
-define(wxTopLevelWindow_SetTitle, 309).
-define(wxTopLevelWindow_ShowFullScreen, 310).
-define(wxFrame_new_0, 311).
-define(wxFrame_new_4, 312).
-define(wxFrame_destruct, 313).
-define(wxFrame_Create, 314).
-define(wxFrame_CreateStatusBar, 315).
-define(wxFrame_CreateToolBar, 316).
-define(wxFrame_GetClientAreaOrigin, 317).
-define(wxFrame_GetMenuBar, 318).
-define(wxFrame_GetStatusBar, 319).
-define(wxFrame_GetStatusBarPane, 320).
-define(wxFrame_GetToolBar, 321).
-define(wxFrame_ProcessCommand, 322).
-define(wxFrame_SendSizeEvent, 323).
-define(wxFrame_SetMenuBar, 324).
-define(wxFrame_SetStatusBar, 325).
-define(wxFrame_SetStatusBarPane, 326).
-define(wxFrame_SetStatusText, 327).
-define(wxFrame_SetStatusWidths, 328).
-define(wxFrame_SetToolBar, 329).
-define(wxMiniFrame_new_0, 330).
-define(wxMiniFrame_new_4, 331).
-define(wxMiniFrame_destruct, 332).
-define(wxMiniFrame_Create, 333).
-define(wxSplashScreen_new, 334).
-define(wxSplashScreen_destruct, 335).
-define(wxSplashScreen_GetSplashStyle, 336).
-define(wxSplashScreen_GetTimeout, 337).
-define(wxPanel_new_0, 338).
-define(wxPanel_new_2, 339).
-define(wxPanel_destruct, 340).
-define(wxPanel_InitDialog, 341).
-define(wxPanel_SetFocusIgnoringChildren, 342).
-define(wxScrolledWindow_new_0, 343).
-define(wxScrolledWindow_new_2, 344).
-define(wxScrolledWindow_CalcScrolledPosition_4, 345).
-define(wxScrolledWindow_CalcScrolledPosition_1, 346).
-define(wxScrolledWindow_CalcUnscrolledPosition_4, 347).
-define(wxScrolledWindow_CalcUnscrolledPosition_1, 348).
-define(wxScrolledWindow_EnableScrolling, 349).
-define(wxScrolledWindow_GetScrollPixelsPerUnit, 350).
-define(wxScrolledWindow_GetViewStart, 352).
-define(wxScrolledWindow_DoPrepareDC, 353).
-define(wxScrolledWindow_PrepareDC, 354).
-define(wxScrolledWindow_Scroll_2, 355).
-define(wxScrolledWindow_Scroll_1, 356).
-define(wxScrolledWindow_SetScrollbars, 357).
-define(wxScrolledWindow_SetScrollRate, 358).
-define(wxScrolledWindow_SetTargetWindow, 359).
-define(wxScrolledWindow_destroy, 360).
-define(wxSashWindow_new_0, 361).
-define(wxSashWindow_new_2, 362).
-define(wxSashWindow_destruct, 363).
-define(wxSashWindow_GetSashVisible, 364).
-define(wxSashWindow_GetMaximumSizeX, 365).
-define(wxSashWindow_GetMaximumSizeY, 366).
-define(wxSashWindow_GetMinimumSizeX, 367).
-define(wxSashWindow_GetMinimumSizeY, 368).
-define(wxSashWindow_SetMaximumSizeX, 369).
-define(wxSashWindow_SetMaximumSizeY, 370).
-define(wxSashWindow_SetMinimumSizeX, 371).
-define(wxSashWindow_SetMinimumSizeY, 372).
-define(wxSashWindow_SetSashVisible, 373).
-define(wxSashLayoutWindow_new_0, 374).
-define(wxSashLayoutWindow_new_2, 375).
-define(wxSashLayoutWindow_Create, 376).
-define(wxSashLayoutWindow_GetAlignment, 377).
-define(wxSashLayoutWindow_GetOrientation, 378).
-define(wxSashLayoutWindow_SetAlignment, 379).
-define(wxSashLayoutWindow_SetDefaultSize, 380).
-define(wxSashLayoutWindow_SetOrientation, 381).
-define(wxSashLayoutWindow_destroy, 382).
-define(wxGrid_new_0, 383).
-define(wxGrid_new_3, 384).
-define(wxGrid_destruct, 385).
-define(wxGrid_AppendCols, 386).
-define(wxGrid_AppendRows, 387).
-define(wxGrid_AutoSize, 388).
-define(wxGrid_AutoSizeColumn, 389).
-define(wxGrid_AutoSizeColumns, 390).
-define(wxGrid_AutoSizeRow, 391).
-define(wxGrid_AutoSizeRows, 392).
-define(wxGrid_BeginBatch, 393).
-define(wxGrid_BlockToDeviceRect, 394).
-define(wxGrid_CanDragCell, 395).
-define(wxGrid_CanDragColMove, 396).
-define(wxGrid_CanDragGridRowEdges, 397).
-define(wxGrid_CanDragColSize, 398).
-define(wxGrid_CanDragRowSize, 399).
-define(wxGrid_CanDragGridSize, 400).
-define(wxGrid_CanEnableCellControl, 401).
-define(wxGrid_CellToRect_2, 402).
-define(wxGrid_CellToRect_1, 403).
-define(wxGrid_ClearGrid, 404).
-define(wxGrid_ClearSelection, 405).
-define(wxGrid_CreateGrid, 406).
-define(wxGrid_DeleteCols, 407).
-define(wxGrid_DeleteRows, 408).
-define(wxGrid_DisableCellEditControl, 409).
-define(wxGrid_DisableDragColSize, 410).
-define(wxGrid_DisableDragGridSize, 411).
-define(wxGrid_DisableDragRowSize, 412).
-define(wxGrid_EnableCellEditControl, 413).
-define(wxGrid_EnableDragColSize, 414).
-define(wxGrid_EnableDragGridSize, 415).
-define(wxGrid_EnableDragRowSize, 416).
-define(wxGrid_EnableEditing, 417).
-define(wxGrid_EnableGridLines, 418).
-define(wxGrid_EndBatch, 419).
-define(wxGrid_Fit, 420).
-define(wxGrid_ForceRefresh, 421).
-define(wxGrid_GetBatchCount, 422).
-define(wxGrid_GetCellAlignment, 423).
-define(wxGrid_GetCellBackgroundColour, 424).
-define(wxGrid_GetCellEditor, 425).
-define(wxGrid_GetCellFont, 426).
-define(wxGrid_GetCellRenderer, 427).
-define(wxGrid_GetCellTextColour, 428).
-define(wxGrid_GetCellValue_2, 429).
-define(wxGrid_GetCellValue_1, 430).
-define(wxGrid_GetColLabelAlignment, 431).
-define(wxGrid_GetColLabelSize, 432).
-define(wxGrid_GetColLabelValue, 433).
-define(wxGrid_GetColMinimalAcceptableWidth, 434).
-define(wxGrid_GetDefaultCellAlignment, 435).
-define(wxGrid_GetDefaultCellBackgroundColour, 436).
-define(wxGrid_GetDefaultCellFont, 437).
-define(wxGrid_GetDefaultCellTextColour, 438).
-define(wxGrid_GetDefaultColLabelSize, 439).
-define(wxGrid_GetDefaultColSize, 440).
-define(wxGrid_GetDefaultEditor, 441).
-define(wxGrid_GetDefaultEditorForCell_2, 442).
-define(wxGrid_GetDefaultEditorForCell_1, 443).
-define(wxGrid_GetDefaultEditorForType, 444).
-define(wxGrid_GetDefaultRenderer, 445).
-define(wxGrid_GetDefaultRendererForCell, 446).
-define(wxGrid_GetDefaultRendererForType, 447).
-define(wxGrid_GetDefaultRowLabelSize, 448).
-define(wxGrid_GetDefaultRowSize, 449).
-define(wxGrid_GetGridCursorCol, 450).
-define(wxGrid_GetGridCursorRow, 451).
-define(wxGrid_GetGridLineColour, 452).
-define(wxGrid_GridLinesEnabled, 453).
-define(wxGrid_GetLabelBackgroundColour, 454).
-define(wxGrid_GetLabelFont, 455).
-define(wxGrid_GetLabelTextColour, 456).
-define(wxGrid_GetNumberCols, 457).
-define(wxGrid_GetNumberRows, 458).
-define(wxGrid_GetOrCreateCellAttr, 459).
-define(wxGrid_GetRowMinimalAcceptableHeight, 460).
-define(wxGrid_GetRowLabelAlignment, 461).
-define(wxGrid_GetRowLabelSize, 462).
-define(wxGrid_GetRowLabelValue, 463).
-define(wxGrid_GetRowSize, 464).
-define(wxGrid_GetScrollLineX, 465).
-define(wxGrid_GetScrollLineY, 466).
-define(wxGrid_GetSelectedCells, 467).
-define(wxGrid_GetSelectedCols, 468).
-define(wxGrid_GetSelectedRows, 469).
-define(wxGrid_GetSelectionBackground, 470).
-define(wxGrid_GetSelectionBlockTopLeft, 471).
-define(wxGrid_GetSelectionBlockBottomRight, 472).
-define(wxGrid_GetSelectionForeground, 473).
-define(wxGrid_GetGridWindow, 474).
-define(wxGrid_GetGridRowLabelWindow, 475).
-define(wxGrid_GetGridColLabelWindow, 476).
-define(wxGrid_GetGridCornerLabelWindow, 477).
-define(wxGrid_HideCellEditControl, 478).
-define(wxGrid_InsertCols, 479).
-define(wxGrid_InsertRows, 480).
-define(wxGrid_IsCellEditControlEnabled, 481).
-define(wxGrid_IsCurrentCellReadOnly, 482).
-define(wxGrid_IsEditable, 483).
-define(wxGrid_IsInSelection_2, 484).
-define(wxGrid_IsInSelection_1, 485).
-define(wxGrid_IsReadOnly, 486).
-define(wxGrid_IsSelection, 487).
-define(wxGrid_IsVisible_3, 488).
-define(wxGrid_IsVisible_2, 489).
-define(wxGrid_MakeCellVisible_2, 490).
-define(wxGrid_MakeCellVisible_1, 491).
-define(wxGrid_MoveCursorDown, 492).
-define(wxGrid_MoveCursorLeft, 493).
-define(wxGrid_MoveCursorRight, 494).
-define(wxGrid_MoveCursorUp, 495).
-define(wxGrid_MoveCursorDownBlock, 496).
-define(wxGrid_MoveCursorLeftBlock, 497).
-define(wxGrid_MoveCursorRightBlock, 498).
-define(wxGrid_MoveCursorUpBlock, 499).
-define(wxGrid_MovePageDown, 500).
-define(wxGrid_MovePageUp, 501).
-define(wxGrid_RegisterDataType, 502).
-define(wxGrid_SaveEditControlValue, 503).
-define(wxGrid_SelectAll, 504).
-define(wxGrid_SelectBlock_5, 505).
-define(wxGrid_SelectBlock_3, 506).
-define(wxGrid_SelectCol, 507).
-define(wxGrid_SelectRow, 508).
-define(wxGrid_SetCellAlignment, 509).
-define(wxGrid_SetCellBackgroundColour, 510).
-define(wxGrid_SetCellEditor, 511).
-define(wxGrid_SetCellFont, 512).
-define(wxGrid_SetCellRenderer, 513).
-define(wxGrid_SetCellTextColour, 514).
-define(wxGrid_SetCellValue_3, 515).
-define(wxGrid_SetCellValue_2, 516).
-define(wxGrid_SetColAttr, 517).
-define(wxGrid_SetColFormatBool, 518).
-define(wxGrid_SetColFormatNumber, 519).
-define(wxGrid_SetColFormatFloat, 520).
-define(wxGrid_SetColFormatCustom, 521).
-define(wxGrid_SetColLabelAlignment, 522).
-define(wxGrid_SetColLabelSize, 523).
-define(wxGrid_SetColLabelValue, 524).
-define(wxGrid_SetColMinimalWidth, 525).
-define(wxGrid_SetColMinimalAcceptableWidth, 526).
-define(wxGrid_SetColSize, 527).
-define(wxGrid_SetDefaultCellAlignment, 528).
-define(wxGrid_SetDefaultCellBackgroundColour, 529).
-define(wxGrid_SetDefaultCellFont, 530).
-define(wxGrid_SetDefaultCellTextColour, 531).
-define(wxGrid_SetDefaultEditor, 532).
-define(wxGrid_SetDefaultRenderer, 533).
-define(wxGrid_SetDefaultColSize, 534).
-define(wxGrid_SetDefaultRowSize, 535).
-define(wxGrid_SetGridCursor_2, 536).
-define(wxGrid_SetGridCursor_1, 537).
-define(wxGrid_SetGridLineColour, 538).
-define(wxGrid_SetLabelBackgroundColour, 539).
-define(wxGrid_SetLabelFont, 540).
-define(wxGrid_SetLabelTextColour, 541).
-define(wxGrid_SetMargins, 542).
-define(wxGrid_SetReadOnly, 543).
-define(wxGrid_SetRowAttr, 544).
-define(wxGrid_SetRowLabelAlignment, 545).
-define(wxGrid_SetRowLabelSize, 546).
-define(wxGrid_SetRowLabelValue, 547).
-define(wxGrid_SetRowMinimalHeight, 548).
-define(wxGrid_SetRowMinimalAcceptableHeight, 549).
-define(wxGrid_SetRowSize, 550).
-define(wxGrid_SetScrollLineX, 551).
-define(wxGrid_SetScrollLineY, 552).
-define(wxGrid_SetSelectionBackground, 553).
-define(wxGrid_SetSelectionForeground, 554).
-define(wxGrid_SetSelectionMode, 555).
-define(wxGrid_ShowCellEditControl, 556).
-define(wxGrid_XToCol, 557).
-define(wxGrid_XToEdgeOfCol, 558).
-define(wxGrid_YToEdgeOfRow, 559).
-define(wxGrid_YToRow, 560).
-define(wxGridCellRenderer_Draw, 561).
-define(wxGridCellRenderer_GetBestSize, 562).
-define(wxGridCellEditor_Create, 563).
-define(wxGridCellEditor_IsCreated, 564).
-define(wxGridCellEditor_SetSize, 565).
-define(wxGridCellEditor_Show, 566).
-define(wxGridCellEditor_Reset, 567).
-define(wxGridCellEditor_StartingKey, 568).
-define(wxGridCellEditor_StartingClick, 569).
-define(wxGridCellEditor_HandleReturn, 570).
-define(wxGridCellBoolRenderer_new, 571).
-define(wxGridCellBoolRenderer_destroy, 572).
-define(wxGridCellBoolEditor_new, 573).
-define(wxGridCellBoolEditor_IsTrueValue, 574).
-define(wxGridCellBoolEditor_UseStringValues, 575).
-define(wxGridCellBoolEditor_destroy, 576).
-define(wxGridCellFloatRenderer_new, 577).
-define(wxGridCellFloatRenderer_GetPrecision, 578).
-define(wxGridCellFloatRenderer_GetWidth, 579).
-define(wxGridCellFloatRenderer_SetParameters, 580).
-define(wxGridCellFloatRenderer_SetPrecision, 581).
-define(wxGridCellFloatRenderer_SetWidth, 582).
-define(wxGridCellFloatRenderer_destroy, 583).
-define(wxGridCellFloatEditor_new, 584).
-define(wxGridCellFloatEditor_SetParameters, 585).
-define(wxGridCellFloatEditor_destroy, 586).
-define(wxGridCellStringRenderer_new, 587).
-define(wxGridCellStringRenderer_destroy, 588).
-define(wxGridCellTextEditor_new, 589).
-define(wxGridCellTextEditor_SetParameters, 590).
-define(wxGridCellTextEditor_destroy, 591).
-define(wxGridCellChoiceEditor_new, 593).
-define(wxGridCellChoiceEditor_SetParameters, 594).
-define(wxGridCellChoiceEditor_destroy, 595).
-define(wxGridCellNumberRenderer_new, 596).
-define(wxGridCellNumberRenderer_destroy, 597).
-define(wxGridCellNumberEditor_new, 598).
-define(wxGridCellNumberEditor_GetValue, 599).
-define(wxGridCellNumberEditor_SetParameters, 600).
-define(wxGridCellNumberEditor_destroy, 601).
-define(wxGridCellAttr_SetTextColour, 602).
-define(wxGridCellAttr_SetBackgroundColour, 603).
-define(wxGridCellAttr_SetFont, 604).
-define(wxGridCellAttr_SetAlignment, 605).
-define(wxGridCellAttr_SetReadOnly, 606).
-define(wxGridCellAttr_SetRenderer, 607).
-define(wxGridCellAttr_SetEditor, 608).
-define(wxGridCellAttr_HasTextColour, 609).
-define(wxGridCellAttr_HasBackgroundColour, 610).
-define(wxGridCellAttr_HasFont, 611).
-define(wxGridCellAttr_HasAlignment, 612).
-define(wxGridCellAttr_HasRenderer, 613).
-define(wxGridCellAttr_HasEditor, 614).
-define(wxGridCellAttr_GetTextColour, 615).
-define(wxGridCellAttr_GetBackgroundColour, 616).
-define(wxGridCellAttr_GetFont, 617).
-define(wxGridCellAttr_GetAlignment, 618).
-define(wxGridCellAttr_GetRenderer, 619).
-define(wxGridCellAttr_GetEditor, 620).
-define(wxGridCellAttr_IsReadOnly, 621).
-define(wxGridCellAttr_SetDefAttr, 622).
-define(wxDC_Blit, 623).
-define(wxDC_CalcBoundingBox, 624).
-define(wxDC_Clear, 625).
-define(wxDC_CrossHair, 626).
-define(wxDC_DestroyClippingRegion, 627).
-define(wxDC_DeviceToLogicalX, 628).
-define(wxDC_DeviceToLogicalXRel, 629).
-define(wxDC_DeviceToLogicalY, 630).
-define(wxDC_DeviceToLogicalYRel, 631).
-define(wxDC_DrawArc, 632).
-define(wxDC_DrawBitmap, 633).
-define(wxDC_DrawCheckMark, 634).
-define(wxDC_DrawCircle, 635).
-define(wxDC_DrawEllipse_2, 637).
-define(wxDC_DrawEllipse_1, 638).
-define(wxDC_DrawEllipticArc, 639).
-define(wxDC_DrawIcon, 640).
-define(wxDC_DrawLabel, 641).
-define(wxDC_DrawLine, 642).
-define(wxDC_DrawLines, 643).
-define(wxDC_DrawPolygon, 645).
-define(wxDC_DrawPoint, 647).
-define(wxDC_DrawRectangle_2, 649).
-define(wxDC_DrawRectangle_1, 650).
-define(wxDC_DrawRotatedText, 651).
-define(wxDC_DrawRoundedRectangle_3, 653).
-define(wxDC_DrawRoundedRectangle_2, 654).
-define(wxDC_DrawText, 655).
-define(wxDC_EndDoc, 656).
-define(wxDC_EndPage, 657).
-define(wxDC_FloodFill, 658).
-define(wxDC_GetBackground, 659).
-define(wxDC_GetBackgroundMode, 660).
-define(wxDC_GetBrush, 661).
-define(wxDC_GetCharHeight, 662).
-define(wxDC_GetCharWidth, 663).
-define(wxDC_GetClippingBox, 664).
-define(wxDC_GetFont, 665).
-define(wxDC_GetLayoutDirection, 666).
-define(wxDC_GetLogicalFunction, 667).
-define(wxDC_GetMapMode, 668).
-define(wxDC_GetMultiLineTextExtent_4, 669).
-define(wxDC_GetMultiLineTextExtent_1, 670).
-define(wxDC_GetPartialTextExtents, 671).
-define(wxDC_GetPen, 672).
-define(wxDC_GetPixel, 673).
-define(wxDC_GetPPI, 674).
-define(wxDC_GetSize, 676).
-define(wxDC_GetSizeMM, 678).
-define(wxDC_GetTextBackground, 679).
-define(wxDC_GetTextExtent_4, 680).
-define(wxDC_GetTextExtent_1, 681).
-define(wxDC_GetTextForeground, 682).
-define(wxDC_GetUserScale, 683).
-define(wxDC_GradientFillConcentric_3, 684).
-define(wxDC_GradientFillConcentric_4, 685).
-define(wxDC_GradientFillLinear, 686).
-define(wxDC_LogicalToDeviceX, 687).
-define(wxDC_LogicalToDeviceXRel, 688).
-define(wxDC_LogicalToDeviceY, 689).
-define(wxDC_LogicalToDeviceYRel, 690).
-define(wxDC_MaxX, 691).
-define(wxDC_MaxY, 692).
-define(wxDC_MinX, 693).
-define(wxDC_MinY, 694).
-define(wxDC_IsOk, 695).
-define(wxDC_ResetBoundingBox, 696).
-define(wxDC_SetAxisOrientation, 697).
-define(wxDC_SetBackground, 698).
-define(wxDC_SetBackgroundMode, 699).
-define(wxDC_SetBrush, 700).
-define(wxDC_SetClippingRegion_2, 702).
-define(wxDC_SetClippingRegion_1, 703).
-define(wxDC_SetDeviceOrigin, 704).
-define(wxDC_SetFont, 705).
-define(wxDC_SetLayoutDirection, 706).
-define(wxDC_SetLogicalFunction, 707).
-define(wxDC_SetMapMode, 708).
-define(wxDC_SetPalette, 709).
-define(wxDC_SetPen, 710).
-define(wxDC_SetTextBackground, 711).
-define(wxDC_SetTextForeground, 712).
-define(wxDC_SetUserScale, 713).
-define(wxDC_StartDoc, 714).
-define(wxDC_StartPage, 715).
-define(wxMirrorDC_new, 716).
-define(wxMirrorDC_destroy, 717).
-define(wxScreenDC_new, 718).
-define(wxScreenDC_destroy, 719).
-define(wxPostScriptDC_new_0, 720).
-define(wxPostScriptDC_new_1, 721).
-define(wxPostScriptDC_destroy, 722).
-define(wxWindowDC_new, 723).
-define(wxWindowDC_destroy, 724).
-define(wxClientDC_new, 725).
-define(wxClientDC_destroy, 726).
-define(wxPaintDC_new, 727).
-define(wxPaintDC_destroy, 728).
-define(wxMemoryDC_new_0, 729).
-define(wxMemoryDC_new_1, 730).
-define(wxMemoryDC_SelectObject, 732).
-define(wxMemoryDC_SelectObjectAsSource, 733).
-define(wxMemoryDC_destroy, 734).
-define(wxBufferedDC_new_0, 735).
-define(wxBufferedDC_new_3, 736).
-define(wxBufferedDC_new_2, 737).
-define(wxBufferedDC_destruct, 738).
-define(wxBufferedDC_Init_3, 739).
-define(wxBufferedDC_Init_2, 740).
-define(wxBufferedPaintDC_new_3, 741).
-define(wxBufferedPaintDC_new_2, 742).
-define(wxBufferedPaintDC_destruct, 743).
-define(wxGraphicsObject_destruct, 744).
-define(wxGraphicsObject_GetRenderer, 745).
-define(wxGraphicsObject_IsNull, 746).
-define(wxGraphicsContext_destruct, 747).
-define(wxGraphicsContext_Create_STAT_1, 749).
-define(wxGraphicsContext_Create_STAT_0, 752).
-define(wxGraphicsContext_CreatePen, 753).
-define(wxGraphicsContext_CreateBrush, 754).
-define(wxGraphicsContext_CreateRadialGradientBrush_7, 755).
-define(wxGraphicsContext_CreateRadialGradientBrush_6, 756).
-define(wxGraphicsContext_CreateLinearGradientBrush_6, 757).
-define(wxGraphicsContext_CreateLinearGradientBrush_5, 758).
-define(wxGraphicsContext_CreateFont_2, 759).
-define(wxGraphicsContext_CreateFont_3, 760).
-define(wxGraphicsContext_CreateMatrix, 761).
-define(wxGraphicsContext_CreatePath, 762).
-define(wxGraphicsContext_Clip_1, 763).
-define(wxGraphicsContext_Clip_4, 764).
-define(wxGraphicsContext_ResetClip, 765).
-define(wxGraphicsContext_DrawBitmap, 766).
-define(wxGraphicsContext_DrawEllipse, 767).
-define(wxGraphicsContext_DrawIcon, 768).
-define(wxGraphicsContext_DrawLines, 769).
-define(wxGraphicsContext_DrawPath, 770).
-define(wxGraphicsContext_DrawRectangle, 771).
-define(wxGraphicsContext_DrawRoundedRectangle, 772).
-define(wxGraphicsContext_DrawText_3, 773).
-define(wxGraphicsContext_DrawText_4_0, 774).
-define(wxGraphicsContext_DrawText_4_1, 775).
-define(wxGraphicsContext_DrawText_5, 776).
-define(wxGraphicsContext_FillPath, 777).
-define(wxGraphicsContext_StrokePath, 778).
-define(wxGraphicsContext_GetPartialTextExtents, 779).
-define(wxGraphicsContext_GetTextExtent, 780).
-define(wxGraphicsContext_Rotate, 781).
-define(wxGraphicsContext_Scale, 782).
-define(wxGraphicsContext_Translate, 783).
-define(wxGraphicsContext_GetTransform, 784).
-define(wxGraphicsContext_SetTransform, 785).
-define(wxGraphicsContext_ConcatTransform, 786).
-define(wxGraphicsContext_SetBrush, 788).
-define(wxGraphicsContext_SetFont_2, 789).
-define(wxGraphicsContext_SetFont_1, 790).
-define(wxGraphicsContext_SetPen, 791).
-define(wxGraphicsContext_StrokeLine, 793).
-define(wxGraphicsContext_StrokeLines, 795).
-define(wxGraphicsMatrix_Concat, 796).
-define(wxGraphicsMatrix_Get, 798).
-define(wxGraphicsMatrix_Invert, 799).
-define(wxGraphicsMatrix_IsEqual, 800).
-define(wxGraphicsMatrix_IsIdentity, 802).
-define(wxGraphicsMatrix_Rotate, 803).
-define(wxGraphicsMatrix_Scale, 804).
-define(wxGraphicsMatrix_Translate, 805).
-define(wxGraphicsMatrix_Set, 806).
-define(wxGraphicsMatrix_TransformPoint, 807).
-define(wxGraphicsMatrix_TransformDistance, 808).
-define(wxGraphicsPath_MoveToPoint_2, 809).
-define(wxGraphicsPath_MoveToPoint_1, 810).
-define(wxGraphicsPath_AddArc_6, 811).
-define(wxGraphicsPath_AddArc_5, 812).
-define(wxGraphicsPath_AddArcToPoint, 813).
-define(wxGraphicsPath_AddCircle, 814).
-define(wxGraphicsPath_AddCurveToPoint_6, 815).
-define(wxGraphicsPath_AddCurveToPoint_3, 816).
-define(wxGraphicsPath_AddEllipse, 817).
-define(wxGraphicsPath_AddLineToPoint_2, 818).
-define(wxGraphicsPath_AddLineToPoint_1, 819).
-define(wxGraphicsPath_AddPath, 820).
-define(wxGraphicsPath_AddQuadCurveToPoint, 821).
-define(wxGraphicsPath_AddRectangle, 822).
-define(wxGraphicsPath_AddRoundedRectangle, 823).
-define(wxGraphicsPath_CloseSubpath, 824).
-define(wxGraphicsPath_Contains_2, 825).
-define(wxGraphicsPath_Contains_3, 826).
-define(wxGraphicsPath_GetBox, 827).
-define(wxGraphicsPath_GetCurrentPoint, 830).
-define(wxGraphicsPath_Transform, 831).
-define(wxGraphicsRenderer_GetDefaultRenderer, 832).
-define(wxGraphicsRenderer_CreateContext, 834).
-define(wxGraphicsRenderer_CreateBrush, 836).
-define(wxGraphicsRenderer_CreateLinearGradientBrush, 837).
-define(wxGraphicsRenderer_CreateRadialGradientBrush, 838).
-define(wxGraphicsRenderer_CreateFont_2, 839).
-define(wxGraphicsRenderer_CreateFont_3, 840).
-define(wxGraphicsRenderer_CreateMatrix, 841).
-define(wxGraphicsRenderer_CreatePath, 842).
-define(wxGraphicsGradientStops_new, 843).
-define(wxGraphicsGradientStops_Item, 844).
-define(wxGraphicsGradientStops_GetCount, 845).
-define(wxGraphicsGradientStops_SetStartColour, 846).
-define(wxGraphicsGradientStops_GetStartColour, 847).
-define(wxGraphicsGradientStops_SetEndColour, 848).
-define(wxGraphicsGradientStops_GetEndColour, 849).
-define(wxGraphicsGradientStops_Add, 850).
-define(wxGraphicsGradientStops_destroy, 851).
-define(wxMenuBar_new_0, 852).
-define(wxMenuBar_new_1, 853).
-define(wxMenuBar_destruct, 855).
-define(wxMenuBar_Append, 856).
-define(wxMenuBar_Check, 857).
-define(wxMenuBar_Enable, 858).
-define(wxMenuBar_EnableTop, 859).
-define(wxMenuBar_FindMenu, 860).
-define(wxMenuBar_FindMenuItem, 861).
-define(wxMenuBar_FindItem, 862).
-define(wxMenuBar_GetHelpString, 863).
-define(wxMenuBar_GetLabel, 864).
-define(wxMenuBar_GetMenuLabel, 865).
-define(wxMenuBar_GetMenuLabelText, 866).
-define(wxMenuBar_GetMenu, 867).
-define(wxMenuBar_GetMenuCount, 868).
-define(wxMenuBar_Insert, 869).
-define(wxMenuBar_IsChecked, 870).
-define(wxMenuBar_SetAutoWindowMenu, 871).
-define(wxMenuBar_GetAutoWindowMenu, 872).
-define(wxMenuBar_OSXGetAppleMenu, 873).
-define(wxMenuBar_MacGetCommonMenuBar, 874).
-define(wxMenuBar_MacSetCommonMenuBar, 875).
-define(wxMenuBar_IsEnabled, 876).
-define(wxMenuBar_Remove, 877).
-define(wxMenuBar_Replace, 878).
-define(wxMenuBar_SetHelpString, 879).
-define(wxMenuBar_SetLabel, 880).
-define(wxMenuBar_SetMenuLabel, 881).
-define(wxControl_GetLabel, 882).
-define(wxControl_SetLabel, 883).
-define(wxControlWithItems_Append_1, 884).
-define(wxControlWithItems_Append_2, 885).
-define(wxControlWithItems_appendStrings_1, 886).
-define(wxControlWithItems_appendStrings_2, 887).
-define(wxControlWithItems_Clear, 888).
-define(wxControlWithItems_Delete, 889).
-define(wxControlWithItems_FindString, 890).
-define(wxControlWithItems_getClientData, 891).
-define(wxControlWithItems_setClientData, 892).
-define(wxControlWithItems_GetCount, 893).
-define(wxControlWithItems_GetSelection, 894).
-define(wxControlWithItems_GetString, 895).
-define(wxControlWithItems_GetStringSelection, 896).
-define(wxControlWithItems_Insert_2, 897).
-define(wxControlWithItems_Insert_3, 898).
-define(wxControlWithItems_insertStrings_2, 899).
-define(wxControlWithItems_insertStrings_3, 900).
-define(wxControlWithItems_IsEmpty, 901).
-define(wxControlWithItems_Select, 902).
-define(wxControlWithItems_SetSelection, 903).
-define(wxControlWithItems_SetString, 904).
-define(wxControlWithItems_SetStringSelection, 905).
-define(wxMenu_new_0, 906).
-define(wxMenu_new_1, 907).
-define(wxMenu_new_2, 908).
-define(wxMenu_destruct, 909).
-define(wxMenu_Append_3, 910).
-define(wxMenu_Append_4, 911).
-define(wxMenu_Append_1, 912).
-define(wxMenu_AppendCheckItem, 913).
-define(wxMenu_AppendRadioItem, 914).
-define(wxMenu_AppendSeparator, 915).
-define(wxMenu_Break, 916).
-define(wxMenu_Check, 917).
-define(wxMenu_Delete_1_0, 918).
-define(wxMenu_Delete_1_1, 919).
-define(wxMenu_Destroy_1_0, 920).
-define(wxMenu_Destroy_1_1, 921).
-define(wxMenu_Enable, 922).
-define(wxMenu_FindItem_1, 923).
-define(wxMenu_FindItem_2, 924).
-define(wxMenu_FindItemByPosition, 925).
-define(wxMenu_GetHelpString, 926).
-define(wxMenu_GetLabel, 927).
-define(wxMenu_GetMenuItemCount, 928).
-define(wxMenu_GetMenuItems, 930).
-define(wxMenu_GetTitle, 931).
-define(wxMenu_Insert_2, 932).
-define(wxMenu_Insert_3, 933).
-define(wxMenu_Insert_5, 934).
-define(wxMenu_InsertCheckItem, 935).
-define(wxMenu_InsertRadioItem, 936).
-define(wxMenu_InsertSeparator, 937).
-define(wxMenu_IsChecked, 938).
-define(wxMenu_IsEnabled, 939).
-define(wxMenu_Prepend_1, 940).
-define(wxMenu_Prepend_2, 941).
-define(wxMenu_Prepend_4, 942).
-define(wxMenu_PrependCheckItem, 943).
-define(wxMenu_PrependRadioItem, 944).
-define(wxMenu_PrependSeparator, 945).
-define(wxMenu_Remove_1_0, 946).
-define(wxMenu_Remove_1_1, 947).
-define(wxMenu_SetHelpString, 948).
-define(wxMenu_SetLabel, 949).
-define(wxMenu_SetTitle, 950).
-define(wxMenuItem_new, 951).
-define(wxMenuItem_destruct, 952).
-define(wxMenuItem_Check, 953).
-define(wxMenuItem_Enable, 954).
-define(wxMenuItem_GetBitmap, 955).
-define(wxMenuItem_GetHelp, 956).
-define(wxMenuItem_GetId, 957).
-define(wxMenuItem_GetKind, 958).
-define(wxMenuItem_GetLabelText, 959).
-define(wxMenuItem_GetItemLabel, 960).
-define(wxMenuItem_GetItemLabelText, 961).
-define(wxMenuItem_GetMenu, 962).
-define(wxMenuItem_GetSubMenu, 963).
-define(wxMenuItem_IsCheckable, 964).
-define(wxMenuItem_IsChecked, 965).
-define(wxMenuItem_IsEnabled, 966).
-define(wxMenuItem_IsSeparator, 967).
-define(wxMenuItem_IsSubMenu, 968).
-define(wxMenuItem_SetBitmap, 969).
-define(wxMenuItem_SetHelp, 970).
-define(wxMenuItem_SetMenu, 971).
-define(wxMenuItem_SetSubMenu, 972).
-define(wxMenuItem_SetItemLabel, 973).
-define(wxToolBar_AddControl, 974).
-define(wxToolBar_AddSeparator, 975).
-define(wxToolBar_AddTool_1, 976).
-define(wxToolBar_AddTool_4, 977).
-define(wxToolBar_AddTool_5, 978).
-define(wxToolBar_AddCheckTool, 979).
-define(wxToolBar_AddRadioTool, 980).
-define(wxToolBar_AddStretchableSpace, 981).
-define(wxToolBar_InsertStretchableSpace, 982).
-define(wxToolBar_DeleteTool, 983).
-define(wxToolBar_DeleteToolByPos, 984).
-define(wxToolBar_EnableTool, 985).
-define(wxToolBar_FindById, 986).
-define(wxToolBar_FindControl, 987).
-define(wxToolBar_FindToolForPosition, 988).
-define(wxToolBar_GetToolSize, 989).
-define(wxToolBar_GetToolBitmapSize, 990).
-define(wxToolBar_GetMargins, 991).
-define(wxToolBar_GetToolEnabled, 992).
-define(wxToolBar_GetToolLongHelp, 993).
-define(wxToolBar_GetToolPacking, 994).
-define(wxToolBar_GetToolPos, 995).
-define(wxToolBar_GetToolSeparation, 996).
-define(wxToolBar_GetToolShortHelp, 997).
-define(wxToolBar_GetToolState, 998).
-define(wxToolBar_InsertControl, 999).
-define(wxToolBar_InsertSeparator, 1000).
-define(wxToolBar_InsertTool_5, 1001).
-define(wxToolBar_InsertTool_2, 1002).
-define(wxToolBar_Realize, 1003).
-define(wxToolBar_RemoveTool, 1004).
-define(wxToolBar_SetMargins, 1005).
-define(wxToolBar_SetToolBitmapSize, 1006).
-define(wxToolBar_SetToolLongHelp, 1007).
-define(wxToolBar_SetToolPacking, 1008).
-define(wxToolBar_SetToolShortHelp, 1009).
-define(wxToolBar_SetToolSeparation, 1010).
-define(wxToolBar_ToggleTool, 1011).
-define(wxStatusBar_new_0, 1012).
-define(wxStatusBar_new_2, 1013).
-define(wxStatusBar_destruct, 1014).
-define(wxStatusBar_Create, 1015).
-define(wxStatusBar_GetFieldRect, 1016).
-define(wxStatusBar_GetFieldsCount, 1017).
-define(wxStatusBar_GetStatusText, 1018).
-define(wxStatusBar_PopStatusText, 1019).
-define(wxStatusBar_PushStatusText, 1020).
-define(wxStatusBar_SetFieldsCount, 1021).
-define(wxStatusBar_SetMinHeight, 1022).
-define(wxStatusBar_SetStatusText, 1023).
-define(wxStatusBar_SetStatusWidths, 1024).
-define(wxStatusBar_SetStatusStyles, 1025).
-define(wxBitmap_new_0, 1026).
-define(wxBitmap_new_4, 1028).
-define(wxBitmap_new_3, 1029).
-define(wxBitmap_new_2_1, 1030).
-define(wxBitmap_new_2_0, 1031).
-define(wxBitmap_new_2_2, 1032).
-define(wxBitmap_new_2_3, 1033).
-define(wxBitmap_destruct, 1034).
-define(wxBitmap_ConvertToImage, 1035).
-define(wxBitmap_CopyFromIcon, 1036).
-define(wxBitmap_Create_3_0, 1037).
-define(wxBitmap_Create_2, 1038).
-define(wxBitmap_Create_3_1, 1039).
-define(wxBitmap_GetDepth, 1040).
-define(wxBitmap_GetHeight, 1041).
-define(wxBitmap_GetPalette, 1042).
-define(wxBitmap_GetMask, 1043).
-define(wxBitmap_GetWidth, 1044).
-define(wxBitmap_GetSubBitmap, 1045).
-define(wxBitmap_LoadFile, 1046).
-define(wxBitmap_IsOk, 1047).
-define(wxBitmap_SaveFile, 1048).
-define(wxBitmap_SetDepth, 1049).
-define(wxBitmap_SetHeight, 1050).
-define(wxBitmap_SetMask, 1051).
-define(wxBitmap_SetPalette, 1052).
-define(wxBitmap_SetWidth, 1053).
-define(wxIcon_new_0, 1054).
-define(wxIcon_new_1, 1055).
-define(wxIcon_new_2, 1056).
-define(wxIcon_CopyFromBitmap, 1057).
-define(wxIcon_destruct, 1058).
-define(wxIconBundle_new_0, 1059).
-define(wxIconBundle_new_1_1, 1060).
-define(wxIconBundle_new_2, 1061).
-define(wxIconBundle_new_1_0, 1063).
-define(wxIconBundle_destruct, 1064).
-define(wxIconBundle_AddIcon_1_0, 1065).
-define(wxIconBundle_AddIcon_2, 1066).
-define(wxIconBundle_AddIcon_1_1, 1067).
-define(wxIconBundle_GetIcon_2, 1068).
-define(wxIconBundle_GetIcon_1, 1069).
-define(wxCursor_new_0, 1070).
-define(wxCursor_new_2, 1071).
-define(wxCursor_new_1_1, 1072).
-define(wxCursor_new_1_0, 1073).
-define(wxCursor_destruct, 1075).
-define(wxCursor_IsOk, 1076).
-define(wxMask_new_0, 1077).
-define(wxMask_new_2_0, 1078).
-define(wxMask_new_1, 1079).
-define(wxMask_new_2_1, 1080).
-define(wxMask_destruct, 1081).
-define(wxMask_Create_2_0, 1082).
-define(wxMask_Create_1, 1083).
-define(wxMask_Create_2_1, 1084).
-define(wxImage_new_0, 1085).
-define(wxImage_new_3_1, 1086).
-define(wxImage_new_2_2, 1087).
-define(wxImage_new_3_0, 1088).
-define(wxImage_new_2_1, 1089).
-define(wxImage_new_4, 1090).
-define(wxImage_new_3_3, 1091).
-define(wxImage_new_2_0, 1092).
-define(wxImage_new_3_2, 1093).
-define(wxImage_destruct, 1094).
-define(wxImage_Blur, 1095).
-define(wxImage_BlurHorizontal, 1096).
-define(wxImage_BlurVertical, 1097).
-define(wxImage_ConvertAlphaToMask_1, 1098).
-define(wxImage_ConvertAlphaToMask_4, 1099).
-define(wxImage_ConvertToGreyscale_3, 1100).
-define(wxImage_ConvertToGreyscale_0, 1101).
-define(wxImage_ConvertToMono, 1102).
-define(wxImage_Copy, 1103).
-define(wxImage_Create_3_1, 1104).
-define(wxImage_Create_2_1, 1105).
-define(wxImage_Create_3_0, 1106).
-define(wxImage_Create_2_0, 1107).
-define(wxImage_Create_4, 1108).
-define(wxImage_Create_3_2, 1109).
-define(wxImage_Destroy, 1110).
-define(wxImage_FindFirstUnusedColour, 1111).
-define(wxImage_GetImageExtWildcard, 1112).
-define(wxImage_GetAlpha_0, 1113).
-define(wxImage_GetAlpha_2, 1114).
-define(wxImage_GetBlue, 1115).
-define(wxImage_GetData, 1116).
-define(wxImage_GetGreen, 1117).
-define(wxImage_GetImageCount, 1118).
-define(wxImage_GetHeight, 1119).
-define(wxImage_GetMaskBlue, 1120).
-define(wxImage_GetMaskGreen, 1121).
-define(wxImage_GetMaskRed, 1122).
-define(wxImage_GetOrFindMaskColour, 1123).
-define(wxImage_GetPalette, 1124).
-define(wxImage_GetRed, 1125).
-define(wxImage_GetSubImage, 1126).
-define(wxImage_GetWidth, 1127).
-define(wxImage_HasAlpha, 1128).
-define(wxImage_HasMask, 1129).
-define(wxImage_GetOption, 1130).
-define(wxImage_GetOptionInt, 1131).
-define(wxImage_HasOption, 1132).
-define(wxImage_InitAlpha, 1133).
-define(wxImage_InitStandardHandlers, 1134).
-define(wxImage_IsTransparent, 1135).
-define(wxImage_LoadFile_2, 1136).
-define(wxImage_LoadFile_3, 1137).
-define(wxImage_IsOk, 1138).
-define(wxImage_RemoveHandler, 1139).
-define(wxImage_Mirror, 1140).
-define(wxImage_Replace, 1141).
-define(wxImage_Rescale, 1142).
-define(wxImage_Resize, 1143).
-define(wxImage_Rotate, 1144).
-define(wxImage_RotateHue, 1145).
-define(wxImage_Rotate90, 1146).
-define(wxImage_SaveFile_2_0, 1147).
-define(wxImage_SaveFile_2_1, 1148).
-define(wxImage_SaveFile_1, 1149).
-define(wxImage_Scale, 1150).
-define(wxImage_Size, 1151).
-define(wxImage_SetAlpha_1, 1152).
-define(wxImage_SetAlpha_3, 1153).
-define(wxImage_SetData_1, 1154).
-define(wxImage_SetData_3, 1155).
-define(wxImage_SetMask, 1156).
-define(wxImage_SetMaskColour, 1157).
-define(wxImage_SetMaskFromImage, 1158).
-define(wxImage_SetOption_2_1, 1159).
-define(wxImage_SetOption_2_0, 1160).
-define(wxImage_SetPalette, 1161).
-define(wxImage_SetRGB_5, 1162).
-define(wxImage_SetRGB_4, 1163).
-define(wxBrush_new_0, 1164).
-define(wxBrush_new_2, 1165).
-define(wxBrush_new_1, 1167).
-define(wxBrush_destruct, 1168).
-define(wxBrush_GetColour, 1169).
-define(wxBrush_GetStipple, 1170).
-define(wxBrush_GetStyle, 1171).
-define(wxBrush_IsHatch, 1172).
-define(wxBrush_IsOk, 1173).
-define(wxBrush_SetColour_1, 1174).
-define(wxBrush_SetColour_3, 1175).
-define(wxBrush_SetStipple, 1176).
-define(wxBrush_SetStyle, 1177).
-define(wxPen_new_0, 1178).
-define(wxPen_new_2, 1179).
-define(wxPen_new_1, 1180).
-define(wxPen_destruct, 1181).
-define(wxPen_GetCap, 1182).
-define(wxPen_GetColour, 1183).
-define(wxPen_GetJoin, 1184).
-define(wxPen_GetStyle, 1185).
-define(wxPen_GetWidth, 1186).
-define(wxPen_IsOk, 1187).
-define(wxPen_SetCap, 1188).
-define(wxPen_SetColour_1, 1189).
-define(wxPen_SetColour_3, 1190).
-define(wxPen_SetJoin, 1191).
-define(wxPen_SetStyle, 1192).
-define(wxPen_SetWidth, 1193).
-define(wxRegion_new_0, 1194).
-define(wxRegion_new_4, 1195).
-define(wxRegion_new_2, 1196).
-define(wxRegion_new_1_0, 1197).
-define(wxRegion_new_1_1, 1199).
-define(wxRegion_destruct, 1201).
-define(wxRegion_Clear, 1202).
-define(wxRegion_Contains_2, 1203).
-define(wxRegion_Contains_1_0, 1204).
-define(wxRegion_Contains_4, 1205).
-define(wxRegion_Contains_1_1, 1206).
-define(wxRegion_ConvertToBitmap, 1207).
-define(wxRegion_GetBox, 1208).
-define(wxRegion_Intersect_4, 1209).
-define(wxRegion_Intersect_1_0, 1210).
-define(wxRegion_Intersect_1_1, 1211).
-define(wxRegion_IsEmpty, 1212).
-define(wxRegion_Subtract_1_0, 1213).
-define(wxRegion_Subtract_1_1, 1214).
-define(wxRegion_Offset_2, 1215).
-define(wxRegion_Offset_1, 1216).
-define(wxRegion_Union_4, 1217).
-define(wxRegion_Union_1_1, 1218).
-define(wxRegion_Union_1_0, 1219).
-define(wxRegion_Union_3, 1221).
-define(wxRegion_Xor_4, 1222).
-define(wxRegion_Xor_1_0, 1223).
-define(wxRegion_Xor_1_1, 1224).
-define(wxAcceleratorTable_new_0, 1225).
-define(wxAcceleratorTable_new_2, 1226).
-define(wxAcceleratorTable_destruct, 1228).
-define(wxAcceleratorTable_IsOk, 1229).
-define(wxAcceleratorEntry_new_1_0, 1230).
-define(wxAcceleratorEntry_new_1_1, 1231).
-define(wxAcceleratorEntry_GetCommand, 1232).
-define(wxAcceleratorEntry_GetFlags, 1233).
-define(wxAcceleratorEntry_GetKeyCode, 1234).
-define(wxAcceleratorEntry_Set, 1235).
-define(wxAcceleratorEntry_destroy, 1236).
-define(wxCaret_new_3, 1238).
-define(wxCaret_new_2, 1239).
-define(wxCaret_Create_3, 1240).
-define(wxCaret_Create_2, 1241).
-define(wxCaret_GetBlinkTime, 1242).
-define(wxCaret_GetPosition, 1244).
-define(wxCaret_GetSize, 1246).
-define(wxCaret_GetWindow, 1247).
-define(wxCaret_Hide, 1248).
-define(wxCaret_IsOk, 1249).
-define(wxCaret_IsVisible, 1250).
-define(wxCaret_Move_2, 1251).
-define(wxCaret_Move_1, 1252).
-define(wxCaret_SetBlinkTime, 1253).
-define(wxCaret_SetSize_2, 1254).
-define(wxCaret_SetSize_1, 1255).
-define(wxCaret_Show, 1256).
-define(wxCaret_destroy, 1257).
-define(wxSizer_Add_2_0, 1258).
-define(wxSizer_Add_2_1, 1259).
-define(wxSizer_Add_3_0, 1262).
-define(wxSizer_Add_3_1, 1263).
-define(wxSizer_AddSpacer, 1264).
-define(wxSizer_AddStretchSpacer, 1265).
-define(wxSizer_CalcMin, 1266).
-define(wxSizer_Clear, 1267).
-define(wxSizer_Detach_1_0, 1268).
-define(wxSizer_Detach_1_1, 1270).
-define(wxSizer_Fit, 1271).
-define(wxSizer_FitInside, 1272).
-define(wxSizer_GetChildren, 1274).
-define(wxSizer_GetItem_2, 1275).
-define(wxSizer_GetItem_1, 1277).
-define(wxSizer_GetSize, 1278).
-define(wxSizer_GetPosition, 1279).
-define(wxSizer_GetMinSize, 1280).
-define(wxSizer_Hide_2, 1281).
-define(wxSizer_Hide_1, 1283).
-define(wxSizer_Insert_3_0, 1284).
-define(wxSizer_Insert_3_1, 1285).
-define(wxSizer_Insert_4_0, 1288).
-define(wxSizer_Insert_4_1, 1289).
-define(wxSizer_Insert_2, 1290).
-define(wxSizer_InsertSpacer, 1291).
-define(wxSizer_InsertStretchSpacer, 1292).
-define(wxSizer_IsShown_1_0, 1293).
-define(wxSizer_IsShown_1_1, 1295).
-define(wxSizer_Layout, 1296).
-define(wxSizer_Prepend_2_0, 1297).
-define(wxSizer_Prepend_2_1, 1298).
-define(wxSizer_Prepend_3_0, 1301).
-define(wxSizer_Prepend_3_1, 1302).
-define(wxSizer_Prepend_1, 1303).
-define(wxSizer_PrependSpacer, 1304).
-define(wxSizer_PrependStretchSpacer, 1305).
-define(wxSizer_Remove_1_1, 1306).
-define(wxSizer_Remove_1_0, 1307).
-define(wxSizer_Replace_3, 1308).
-define(wxSizer_Replace_2, 1310).
-define(wxSizer_SetDimension_4, 1311).
-define(wxSizer_SetDimension_2, 1312).
-define(wxSizer_SetMinSize_1, 1313).
-define(wxSizer_SetMinSize_2, 1314).
-define(wxSizer_SetItemMinSize_3_0, 1315).
-define(wxSizer_SetItemMinSize_2_0, 1316).
-define(wxSizer_SetItemMinSize_3_1, 1319).
-define(wxSizer_SetItemMinSize_2_1, 1320).
-define(wxSizer_SetSizeHints, 1321).
-define(wxSizer_Show_2_0, 1322).
-define(wxSizer_Show_2_1, 1324).
-define(wxSizer_Show_1, 1325).
-define(wxSizer_ShowItems, 1326).
-define(wxSizerFlags_new, 1327).
-define(wxSizerFlags_Align, 1328).
-define(wxSizerFlags_Border_2, 1329).
-define(wxSizerFlags_Border_1, 1330).
-define(wxSizerFlags_Center, 1331).
-define(wxSizerFlags_Expand, 1332).
-define(wxSizerFlags_Left, 1333).
-define(wxSizerFlags_Proportion, 1334).
-define(wxSizerFlags_Right, 1335).
-define(wxSizerFlags_destroy, 1336).
-define(wxSizerItem_new_3, 1337).
-define(wxSizerItem_new_2_0, 1338).
-define(wxSizerItem_new_2_1, 1339).
-define(wxSizerItem_destruct, 1342).
-define(wxSizerItem_CalcMin, 1343).
-define(wxSizerItem_DeleteWindows, 1344).
-define(wxSizerItem_DetachSizer, 1345).
-define(wxSizerItem_GetBorder, 1346).
-define(wxSizerItem_GetFlag, 1347).
-define(wxSizerItem_GetMinSize, 1348).
-define(wxSizerItem_GetPosition, 1349).
-define(wxSizerItem_GetProportion, 1350).
-define(wxSizerItem_GetRatio, 1351).
-define(wxSizerItem_GetRect, 1352).
-define(wxSizerItem_GetSize, 1353).
-define(wxSizerItem_GetSizer, 1354).
-define(wxSizerItem_GetSpacer, 1355).
-define(wxSizerItem_GetUserData, 1356).
-define(wxSizerItem_GetWindow, 1357).
-define(wxSizerItem_IsSizer, 1358).
-define(wxSizerItem_IsShown, 1359).
-define(wxSizerItem_IsSpacer, 1360).
-define(wxSizerItem_IsWindow, 1361).
-define(wxSizerItem_SetBorder, 1362).
-define(wxSizerItem_SetDimension, 1363).
-define(wxSizerItem_SetFlag, 1364).
-define(wxSizerItem_SetInitSize, 1365).
-define(wxSizerItem_SetMinSize_1, 1366).
-define(wxSizerItem_SetMinSize_2, 1367).
-define(wxSizerItem_SetProportion, 1368).
-define(wxSizerItem_SetRatio_2, 1369).
-define(wxSizerItem_SetRatio_1_1, 1370).
-define(wxSizerItem_SetRatio_1_0, 1371).
-define(wxSizerItem_AssignSizer, 1372).
-define(wxSizerItem_AssignSpacer_1, 1373).
-define(wxSizerItem_AssignSpacer_2, 1374).
-define(wxSizerItem_AssignWindow, 1375).
-define(wxSizerItem_Show, 1376).
-define(wxBoxSizer_new, 1377).
-define(wxBoxSizer_GetOrientation, 1378).
-define(wxBoxSizer_destroy, 1379).
-define(wxStaticBoxSizer_new_2, 1380).
-define(wxStaticBoxSizer_new_3, 1381).
-define(wxStaticBoxSizer_GetStaticBox, 1382).
-define(wxStaticBoxSizer_destroy, 1383).
-define(wxGridSizer_new_3_0, 1384).
-define(wxGridSizer_new_2, 1385).
-define(wxGridSizer_new_4, 1386).
-define(wxGridSizer_new_3_1, 1387).
-define(wxGridSizer_GetCols, 1388).
-define(wxGridSizer_GetHGap, 1389).
-define(wxGridSizer_GetRows, 1390).
-define(wxGridSizer_GetVGap, 1391).
-define(wxGridSizer_SetCols, 1392).
-define(wxGridSizer_SetHGap, 1393).
-define(wxGridSizer_SetRows, 1394).
-define(wxGridSizer_SetVGap, 1395).
-define(wxGridSizer_destroy, 1396).
-define(wxFlexGridSizer_new_3_0, 1397).
-define(wxFlexGridSizer_new_2, 1398).
-define(wxFlexGridSizer_new_4, 1399).
-define(wxFlexGridSizer_new_3_1, 1400).
-define(wxFlexGridSizer_AddGrowableCol, 1401).
-define(wxFlexGridSizer_AddGrowableRow, 1402).
-define(wxFlexGridSizer_GetFlexibleDirection, 1403).
-define(wxFlexGridSizer_GetNonFlexibleGrowMode, 1404).
-define(wxFlexGridSizer_RemoveGrowableCol, 1405).
-define(wxFlexGridSizer_RemoveGrowableRow, 1406).
-define(wxFlexGridSizer_SetFlexibleDirection, 1407).
-define(wxFlexGridSizer_SetNonFlexibleGrowMode, 1408).
-define(wxFlexGridSizer_destroy, 1409).
-define(wxGridBagSizer_new, 1410).
-define(wxGridBagSizer_Add_3, 1411).
-define(wxGridBagSizer_Add_1, 1413).
-define(wxGridBagSizer_Add_4, 1414).
-define(wxGridBagSizer_CalcMin, 1415).
-define(wxGridBagSizer_CheckForIntersection_2, 1416).
-define(wxGridBagSizer_CheckForIntersection_3, 1417).
-define(wxGridBagSizer_FindItem, 1418).
-define(wxGridBagSizer_FindItemAtPoint, 1420).
-define(wxGridBagSizer_FindItemAtPosition, 1421).
-define(wxGridBagSizer_FindItemWithData, 1422).
-define(wxGridBagSizer_GetCellSize, 1423).
-define(wxGridBagSizer_GetEmptyCellSize, 1424).
-define(wxGridBagSizer_GetItemPosition_1_0, 1425).
-define(wxGridBagSizer_GetItemPosition_1_1, 1427).
-define(wxGridBagSizer_GetItemSpan_1_0, 1428).
-define(wxGridBagSizer_GetItemSpan_1_1, 1430).
-define(wxGridBagSizer_SetEmptyCellSize, 1431).
-define(wxGridBagSizer_SetItemPosition_2_0, 1432).
-define(wxGridBagSizer_SetItemPosition_2_1, 1434).
-define(wxGridBagSizer_SetItemSpan_2_0, 1435).
-define(wxGridBagSizer_SetItemSpan_2_1, 1437).
-define(wxGridBagSizer_destroy, 1438).
-define(wxStdDialogButtonSizer_new, 1439).
-define(wxStdDialogButtonSizer_AddButton, 1440).
-define(wxStdDialogButtonSizer_Realize, 1441).
-define(wxStdDialogButtonSizer_SetAffirmativeButton, 1442).
-define(wxStdDialogButtonSizer_SetCancelButton, 1443).
-define(wxStdDialogButtonSizer_SetNegativeButton, 1444).
-define(wxStdDialogButtonSizer_destroy, 1445).
-define(wxFont_new_0, 1446).
-define(wxFont_new_1_1, 1447).
-define(wxFont_new_5_0, 1448).
-define(wxFont_new_5_1, 1449).
-define(wxFont_new_1_0, 1450).
-define(wxFont_destruct, 1451).
-define(wxFont_IsFixedWidth, 1452).
-define(wxFont_GetDefaultEncoding, 1453).
-define(wxFont_GetFaceName, 1454).
-define(wxFont_GetFamily, 1455).
-define(wxFont_GetNativeFontInfoDesc, 1456).
-define(wxFont_GetNativeFontInfoUserDesc, 1457).
-define(wxFont_GetPointSize, 1458).
-define(wxFont_GetStyle, 1459).
-define(wxFont_GetUnderlined, 1460).
-define(wxFont_GetWeight, 1461).
-define(wxFont_IsOk, 1462).
-define(wxFont_SetDefaultEncoding, 1463).
-define(wxFont_SetFaceName, 1464).
-define(wxFont_SetFamily, 1465).
-define(wxFont_SetPointSize, 1466).
-define(wxFont_SetStyle, 1467).
-define(wxFont_SetUnderlined, 1468).
-define(wxFont_SetWeight, 1469).
-define(wxToolTip_Enable, 1470).
-define(wxToolTip_SetDelay, 1471).
-define(wxToolTip_new, 1472).
-define(wxToolTip_SetTip, 1473).
-define(wxToolTip_GetTip, 1474).
-define(wxToolTip_GetWindow, 1475).
-define(wxToolTip_destroy, 1476).
-define(wxButton_new_0, 1477).
-define(wxButton_new_3, 1478).
-define(wxButton_Create, 1479).
-define(wxButton_GetDefaultSize_STAT_0, 1480).
-define(wxButton_GetDefaultSize_STAT_1, 1481).
-define(wxButton_SetDefault, 1482).
-define(wxButton_SetLabel, 1483).
-define(wxButton_GetBitmapDisabled, 1484).
-define(wxButton_GetBitmapFocus, 1485).
-define(wxButton_GetBitmapLabel, 1486).
-define(wxButton_SetBitmapDisabled, 1487).
-define(wxButton_SetBitmapFocus, 1488).
-define(wxButton_SetBitmapLabel, 1489).
-define(wxButton_destroy, 1490).
-define(wxBitmapButton_new_0, 1491).
-define(wxBitmapButton_new_4, 1492).
-define(wxBitmapButton_Create, 1493).
-define(wxBitmapButton_NewCloseButton, 1494).
-define(wxBitmapButton_destroy, 1495).
-define(wxToggleButton_new_0, 1496).
-define(wxToggleButton_new_4, 1497).
-define(wxToggleButton_destruct, 1498).
-define(wxToggleButton_Create, 1499).
-define(wxToggleButton_GetValue, 1500).
-define(wxToggleButton_SetValue, 1501).
-define(wxCalendarCtrl_new_0, 1502).
-define(wxCalendarCtrl_new_3, 1503).
-define(wxCalendarCtrl_Create, 1504).
-define(wxCalendarCtrl_destruct, 1505).
-define(wxCalendarCtrl_SetDate, 1506).
-define(wxCalendarCtrl_GetDate, 1507).
-define(wxCalendarCtrl_EnableYearChange, 1508).
-define(wxCalendarCtrl_EnableMonthChange, 1509).
-define(wxCalendarCtrl_EnableHolidayDisplay, 1510).
-define(wxCalendarCtrl_SetHeaderColours, 1511).
-define(wxCalendarCtrl_GetHeaderColourFg, 1512).
-define(wxCalendarCtrl_GetHeaderColourBg, 1513).
-define(wxCalendarCtrl_SetHighlightColours, 1514).
-define(wxCalendarCtrl_GetHighlightColourFg, 1515).
-define(wxCalendarCtrl_GetHighlightColourBg, 1516).
-define(wxCalendarCtrl_SetHolidayColours, 1517).
-define(wxCalendarCtrl_GetHolidayColourFg, 1518).
-define(wxCalendarCtrl_GetHolidayColourBg, 1519).
-define(wxCalendarCtrl_GetAttr, 1520).
-define(wxCalendarCtrl_SetAttr, 1521).
-define(wxCalendarCtrl_SetHoliday, 1522).
-define(wxCalendarCtrl_ResetAttr, 1523).
-define(wxCalendarCtrl_HitTest, 1524).
-define(wxCalendarDateAttr_new_1, 1525).
-define(wxCalendarDateAttr_new_2, 1526).
-define(wxCalendarDateAttr_SetTextColour, 1527).
-define(wxCalendarDateAttr_SetBackgroundColour, 1528).
-define(wxCalendarDateAttr_SetBorderColour, 1529).
-define(wxCalendarDateAttr_SetFont, 1530).
-define(wxCalendarDateAttr_SetBorder, 1531).
-define(wxCalendarDateAttr_SetHoliday, 1532).
-define(wxCalendarDateAttr_HasTextColour, 1533).
-define(wxCalendarDateAttr_HasBackgroundColour, 1534).
-define(wxCalendarDateAttr_HasBorderColour, 1535).
-define(wxCalendarDateAttr_HasFont, 1536).
-define(wxCalendarDateAttr_HasBorder, 1537).
-define(wxCalendarDateAttr_IsHoliday, 1538).
-define(wxCalendarDateAttr_GetTextColour, 1539).
-define(wxCalendarDateAttr_GetBackgroundColour, 1540).
-define(wxCalendarDateAttr_GetBorderColour, 1541).
-define(wxCalendarDateAttr_GetFont, 1542).
-define(wxCalendarDateAttr_GetBorder, 1543).
-define(wxCalendarDateAttr_destroy, 1544).
-define(wxCheckBox_new_0, 1545).
-define(wxCheckBox_new_4, 1546).
-define(wxCheckBox_destruct, 1547).
-define(wxCheckBox_Create, 1548).
-define(wxCheckBox_GetValue, 1549).
-define(wxCheckBox_Get3StateValue, 1550).
-define(wxCheckBox_Is3rdStateAllowedForUser, 1551).
-define(wxCheckBox_Is3State, 1552).
-define(wxCheckBox_IsChecked, 1553).
-define(wxCheckBox_SetValue, 1554).
-define(wxCheckBox_Set3StateValue, 1555).
-define(wxCheckListBox_new_0, 1556).
-define(wxCheckListBox_new_3, 1558).
-define(wxCheckListBox_destruct, 1559).
-define(wxCheckListBox_Check, 1560).
-define(wxCheckListBox_IsChecked, 1561).
-define(wxChoice_new_0, 1562).
-define(wxChoice_new_3, 1564).
-define(wxChoice_destruct, 1565).
-define(wxChoice_Create, 1567).
-define(wxChoice_Delete, 1568).
-define(wxChoice_GetColumns, 1569).
-define(wxChoice_SetColumns, 1570).
-define(wxComboBox_new_0, 1571).
-define(wxComboBox_new_3, 1573).
-define(wxComboBox_destruct, 1574).
-define(wxComboBox_Create, 1576).
-define(wxComboBox_CanCopy, 1577).
-define(wxComboBox_CanCut, 1578).
-define(wxComboBox_CanPaste, 1579).
-define(wxComboBox_CanRedo, 1580).
-define(wxComboBox_CanUndo, 1581).
-define(wxComboBox_Copy, 1582).
-define(wxComboBox_Cut, 1583).
-define(wxComboBox_GetInsertionPoint, 1584).
-define(wxComboBox_GetLastPosition, 1585).
-define(wxComboBox_GetValue, 1586).
-define(wxComboBox_Paste, 1587).
-define(wxComboBox_Redo, 1588).
-define(wxComboBox_Replace, 1589).
-define(wxComboBox_Remove, 1590).
-define(wxComboBox_SetInsertionPoint, 1591).
-define(wxComboBox_SetInsertionPointEnd, 1592).
-define(wxComboBox_SetSelection_2, 1593).
-define(wxComboBox_SetSelection_1, 1594).
-define(wxComboBox_SetValue, 1595).
-define(wxComboBox_Undo, 1596).
-define(wxGauge_new_0, 1597).
-define(wxGauge_new_4, 1598).
-define(wxGauge_destruct, 1599).
-define(wxGauge_Create, 1600).
-define(wxGauge_GetRange, 1601).
-define(wxGauge_GetValue, 1602).
-define(wxGauge_IsVertical, 1603).
-define(wxGauge_SetRange, 1604).
-define(wxGauge_SetValue, 1605).
-define(wxGauge_Pulse, 1606).
-define(wxGenericDirCtrl_new_0, 1607).
-define(wxGenericDirCtrl_new_2, 1608).
-define(wxGenericDirCtrl_destruct, 1609).
-define(wxGenericDirCtrl_Create, 1610).
-define(wxGenericDirCtrl_Init, 1611).
-define(wxGenericDirCtrl_CollapseTree, 1612).
-define(wxGenericDirCtrl_ExpandPath, 1613).
-define(wxGenericDirCtrl_GetDefaultPath, 1614).
-define(wxGenericDirCtrl_GetPath_0, 1615).
-define(wxGenericDirCtrl_GetPath_1, 1616).
-define(wxGenericDirCtrl_GetFilePath, 1617).
-define(wxGenericDirCtrl_GetFilter, 1618).
-define(wxGenericDirCtrl_GetFilterIndex, 1619).
-define(wxGenericDirCtrl_GetRootId, 1620).
-define(wxGenericDirCtrl_GetTreeCtrl, 1621).
-define(wxGenericDirCtrl_ReCreateTree, 1622).
-define(wxGenericDirCtrl_SetDefaultPath, 1623).
-define(wxGenericDirCtrl_SetFilter, 1624).
-define(wxGenericDirCtrl_SetFilterIndex, 1625).
-define(wxGenericDirCtrl_SetPath, 1626).
-define(wxStaticBox_new_0, 1627).
-define(wxStaticBox_new_4, 1628).
-define(wxStaticBox_destruct, 1629).
-define(wxStaticBox_Create, 1630).
-define(wxStaticLine_new_0, 1631).
-define(wxStaticLine_new_2, 1632).
-define(wxStaticLine_Create, 1633).
-define(wxStaticLine_IsVertical, 1634).
-define(wxStaticLine_GetDefaultSize, 1635).
-define(wxStaticLine_destroy, 1636).
-define(wxListBox_new_0, 1637).
-define(wxListBox_new_3, 1639).
-define(wxListBox_destruct, 1640).
-define(wxListBox_Create, 1642).
-define(wxListBox_Deselect, 1643).
-define(wxListBox_GetSelections, 1644).
-define(wxListBox_InsertItems, 1645).
-define(wxListBox_IsSelected, 1646).
-define(wxListBox_Set, 1649).
-define(wxListBox_HitTest_1, 1650).
-define(wxListBox_HitTest_2, 1651).
-define(wxListBox_SetFirstItem_1_0, 1652).
-define(wxListBox_SetFirstItem_1_1, 1653).
-define(wxListCtrl_new_0, 1654).
-define(wxListCtrl_new_2, 1655).
-define(wxListCtrl_destruct, 1656).
-define(wxListCtrl_Arrange, 1657).
-define(wxListCtrl_AssignImageList, 1658).
-define(wxListCtrl_ClearAll, 1659).
-define(wxListCtrl_Create, 1660).
-define(wxListCtrl_DeleteAllItems, 1661).
-define(wxListCtrl_DeleteColumn, 1662).
-define(wxListCtrl_DeleteItem, 1663).
-define(wxListCtrl_EditLabel, 1664).
-define(wxListCtrl_EnsureVisible, 1665).
-define(wxListCtrl_FindItem_3_0, 1666).
-define(wxListCtrl_FindItem_3_1, 1667).
-define(wxListCtrl_GetColumn, 1668).
-define(wxListCtrl_GetColumnCount, 1669).
-define(wxListCtrl_GetColumnWidth, 1670).
-define(wxListCtrl_GetCountPerPage, 1671).
-define(wxListCtrl_GetEditControl, 1672).
-define(wxListCtrl_GetImageList, 1673).
-define(wxListCtrl_GetItem, 1674).
-define(wxListCtrl_GetItemBackgroundColour, 1675).
-define(wxListCtrl_GetItemCount, 1676).
-define(wxListCtrl_GetItemData, 1677).
-define(wxListCtrl_GetItemFont, 1678).
-define(wxListCtrl_GetItemPosition, 1679).
-define(wxListCtrl_GetItemRect, 1680).
-define(wxListCtrl_GetItemSpacing, 1681).
-define(wxListCtrl_GetItemState, 1682).
-define(wxListCtrl_GetItemText, 1683).
-define(wxListCtrl_GetItemTextColour, 1684).
-define(wxListCtrl_GetNextItem, 1685).
-define(wxListCtrl_GetSelectedItemCount, 1686).
-define(wxListCtrl_GetTextColour, 1687).
-define(wxListCtrl_GetTopItem, 1688).
-define(wxListCtrl_GetViewRect, 1689).
-define(wxListCtrl_HitTest, 1690).
-define(wxListCtrl_InsertColumn_2, 1691).
-define(wxListCtrl_InsertColumn_3, 1692).
-define(wxListCtrl_InsertItem_1, 1693).
-define(wxListCtrl_InsertItem_2_1, 1694).
-define(wxListCtrl_InsertItem_2_0, 1695).
-define(wxListCtrl_InsertItem_3, 1696).
-define(wxListCtrl_RefreshItem, 1697).
-define(wxListCtrl_RefreshItems, 1698).
-define(wxListCtrl_ScrollList, 1699).
-define(wxListCtrl_SetBackgroundColour, 1700).
-define(wxListCtrl_SetColumn, 1701).
-define(wxListCtrl_SetColumnWidth, 1702).
-define(wxListCtrl_SetImageList, 1703).
-define(wxListCtrl_SetItem_1, 1704).
-define(wxListCtrl_SetItem_4, 1705).
-define(wxListCtrl_SetItemBackgroundColour, 1706).
-define(wxListCtrl_SetItemCount, 1707).
-define(wxListCtrl_SetItemData, 1708).
-define(wxListCtrl_SetItemFont, 1709).
-define(wxListCtrl_SetItemImage, 1710).
-define(wxListCtrl_SetItemColumnImage, 1711).
-define(wxListCtrl_SetItemPosition, 1712).
-define(wxListCtrl_SetItemState, 1713).
-define(wxListCtrl_SetItemText, 1714).
-define(wxListCtrl_SetItemTextColour, 1715).
-define(wxListCtrl_SetSingleStyle, 1716).
-define(wxListCtrl_SetTextColour, 1717).
-define(wxListCtrl_SetWindowStyleFlag, 1718).
-define(wxListCtrl_SortItems, 1719).
-define(wxListView_ClearColumnImage, 1720).
-define(wxListView_Focus, 1721).
-define(wxListView_GetFirstSelected, 1722).
-define(wxListView_GetFocusedItem, 1723).
-define(wxListView_GetNextSelected, 1724).
-define(wxListView_IsSelected, 1725).
-define(wxListView_Select, 1726).
-define(wxListView_SetColumnImage, 1727).
-define(wxListItem_new_0, 1728).
-define(wxListItem_new_1, 1729).
-define(wxListItem_Clear, 1730).
-define(wxListItem_GetAlign, 1731).
-define(wxListItem_GetBackgroundColour, 1732).
-define(wxListItem_GetColumn, 1733).
-define(wxListItem_GetFont, 1734).
-define(wxListItem_GetId, 1735).
-define(wxListItem_GetImage, 1736).
-define(wxListItem_GetMask, 1737).
-define(wxListItem_GetState, 1738).
-define(wxListItem_GetText, 1739).
-define(wxListItem_GetTextColour, 1740).
-define(wxListItem_GetWidth, 1741).
-define(wxListItem_SetAlign, 1742).
-define(wxListItem_SetBackgroundColour, 1743).
-define(wxListItem_SetColumn, 1744).
-define(wxListItem_SetFont, 1745).
-define(wxListItem_SetId, 1746).
-define(wxListItem_SetImage, 1747).
-define(wxListItem_SetMask, 1748).
-define(wxListItem_SetState, 1749).
-define(wxListItem_SetStateMask, 1750).
-define(wxListItem_SetText, 1751).
-define(wxListItem_SetTextColour, 1752).
-define(wxListItem_SetWidth, 1753).
-define(wxListItem_destroy, 1754).
-define(wxListItemAttr_new_0, 1755).
-define(wxListItemAttr_new_3, 1756).
-define(wxListItemAttr_GetBackgroundColour, 1757).
-define(wxListItemAttr_GetFont, 1758).
-define(wxListItemAttr_GetTextColour, 1759).
-define(wxListItemAttr_HasBackgroundColour, 1760).
-define(wxListItemAttr_HasFont, 1761).
-define(wxListItemAttr_HasTextColour, 1762).
-define(wxListItemAttr_SetBackgroundColour, 1763).
-define(wxListItemAttr_SetFont, 1764).
-define(wxListItemAttr_SetTextColour, 1765).
-define(wxListItemAttr_destroy, 1766).
-define(wxImageList_new_0, 1767).
-define(wxImageList_new_3, 1768).
-define(wxImageList_Add_2_0, 1769).
-define(wxImageList_Add_2_1, 1771).
-define(wxImageList_Add_1, 1772).
-define(wxImageList_Create, 1773).
-define(wxImageList_Draw, 1774).
-define(wxImageList_GetBitmap, 1775).
-define(wxImageList_GetIcon, 1776).
-define(wxImageList_GetImageCount, 1777).
-define(wxImageList_GetSize, 1778).
-define(wxImageList_Remove, 1780).
-define(wxImageList_RemoveAll, 1781).
-define(wxImageList_Replace_3, 1782).
-define(wxImageList_Replace_2, 1784).
-define(wxImageList_destroy, 1785).
-define(wxTextAttr_new_0, 1786).
-define(wxTextAttr_new_2, 1787).
-define(wxTextAttr_new_1, 1788).
-define(wxTextAttr_GetAlignment, 1789).
-define(wxTextAttr_GetBackgroundColour, 1790).
-define(wxTextAttr_GetFont, 1791).
-define(wxTextAttr_GetFontEncoding, 1792).
-define(wxTextAttr_GetFontFaceName, 1793).
-define(wxTextAttr_GetFontSize, 1794).
-define(wxTextAttr_GetFontStyle, 1795).
-define(wxTextAttr_GetFontUnderlined, 1796).
-define(wxTextAttr_GetFontWeight, 1797).
-define(wxTextAttr_GetLeftIndent, 1798).
-define(wxTextAttr_GetLeftSubIndent, 1799).
-define(wxTextAttr_GetRightIndent, 1800).
-define(wxTextAttr_GetTabs, 1801).
-define(wxTextAttr_GetTextColour, 1802).
-define(wxTextAttr_HasBackgroundColour, 1803).
-define(wxTextAttr_HasFont, 1804).
-define(wxTextAttr_HasTextColour, 1805).
-define(wxTextAttr_GetFlags, 1806).
-define(wxTextAttr_IsDefault, 1807).
-define(wxTextAttr_SetAlignment, 1808).
-define(wxTextAttr_SetBackgroundColour, 1809).
-define(wxTextAttr_SetFlags, 1810).
-define(wxTextAttr_SetFont, 1811).
-define(wxTextAttr_SetFontEncoding, 1812).
-define(wxTextAttr_SetFontFaceName, 1813).
-define(wxTextAttr_SetFontFamily, 1814).
-define(wxTextAttr_SetFontSize, 1815).
-define(wxTextAttr_SetFontPointSize, 1816).
-define(wxTextAttr_SetFontPixelSize, 1817).
-define(wxTextAttr_SetFontStyle, 1818).
-define(wxTextAttr_SetFontUnderlined, 1819).
-define(wxTextAttr_SetFontWeight, 1820).
-define(wxTextAttr_SetLeftIndent, 1821).
-define(wxTextAttr_SetRightIndent, 1822).
-define(wxTextAttr_SetTabs, 1823).
-define(wxTextAttr_SetTextColour, 1824).
-define(wxTextAttr_destroy, 1825).
-define(wxTextCtrl_new_0, 1826).
-define(wxTextCtrl_new_3, 1827).
-define(wxTextCtrl_destruct, 1828).
-define(wxTextCtrl_AppendText, 1829).
-define(wxTextCtrl_CanCopy, 1830).
-define(wxTextCtrl_CanCut, 1831).
-define(wxTextCtrl_CanPaste, 1832).
-define(wxTextCtrl_CanRedo, 1833).
-define(wxTextCtrl_CanUndo, 1834).
-define(wxTextCtrl_Clear, 1835).
-define(wxTextCtrl_Copy, 1836).
-define(wxTextCtrl_Create, 1837).
-define(wxTextCtrl_Cut, 1838).
-define(wxTextCtrl_DiscardEdits, 1839).
-define(wxTextCtrl_ChangeValue, 1840).
-define(wxTextCtrl_EmulateKeyPress, 1841).
-define(wxTextCtrl_GetDefaultStyle, 1842).
-define(wxTextCtrl_GetInsertionPoint, 1843).
-define(wxTextCtrl_GetLastPosition, 1844).
-define(wxTextCtrl_GetLineLength, 1845).
-define(wxTextCtrl_GetLineText, 1846).
-define(wxTextCtrl_GetNumberOfLines, 1847).
-define(wxTextCtrl_GetRange, 1848).
-define(wxTextCtrl_GetSelection, 1849).
-define(wxTextCtrl_GetStringSelection, 1850).
-define(wxTextCtrl_GetStyle, 1851).
-define(wxTextCtrl_GetValue, 1852).
-define(wxTextCtrl_IsEditable, 1853).
-define(wxTextCtrl_IsModified, 1854).
-define(wxTextCtrl_IsMultiLine, 1855).
-define(wxTextCtrl_IsSingleLine, 1856).
-define(wxTextCtrl_LoadFile, 1857).
-define(wxTextCtrl_MarkDirty, 1858).
-define(wxTextCtrl_Paste, 1859).
-define(wxTextCtrl_PositionToXY, 1860).
-define(wxTextCtrl_Redo, 1861).
-define(wxTextCtrl_Remove, 1862).
-define(wxTextCtrl_Replace, 1863).
-define(wxTextCtrl_SaveFile, 1864).
-define(wxTextCtrl_SetDefaultStyle, 1865).
-define(wxTextCtrl_SetEditable, 1866).
-define(wxTextCtrl_SetInsertionPoint, 1867).
-define(wxTextCtrl_SetInsertionPointEnd, 1868).
-define(wxTextCtrl_SetMaxLength, 1869).
-define(wxTextCtrl_SetSelection, 1870).
-define(wxTextCtrl_SetStyle, 1871).
-define(wxTextCtrl_SetValue, 1872).
-define(wxTextCtrl_ShowPosition, 1873).
-define(wxTextCtrl_Undo, 1874).
-define(wxTextCtrl_WriteText, 1875).
-define(wxTextCtrl_XYToPosition, 1876).
-define(wxBookCtrlBase_AddPage, 1877).
-define(wxBookCtrlBase_InsertPage, 1878).
-define(wxBookCtrlBase_DeletePage, 1879).
-define(wxBookCtrlBase_RemovePage, 1880).
-define(wxBookCtrlBase_DeleteAllPages, 1881).
-define(wxBookCtrlBase_GetPage, 1882).
-define(wxBookCtrlBase_GetPageCount, 1883).
-define(wxBookCtrlBase_GetCurrentPage, 1884).
-define(wxBookCtrlBase_AdvanceSelection, 1885).
-define(wxBookCtrlBase_SetSelection, 1886).
-define(wxBookCtrlBase_GetSelection, 1887).
-define(wxBookCtrlBase_ChangeSelection, 1888).
-define(wxBookCtrlBase_HitTest, 1889).
-define(wxBookCtrlBase_GetPageText, 1890).
-define(wxBookCtrlBase_SetPageText, 1891).
-define(wxNotebook_new_0, 1892).
-define(wxNotebook_new_3, 1893).
-define(wxNotebook_destruct, 1894).
-define(wxNotebook_AssignImageList, 1895).
-define(wxNotebook_Create, 1896).
-define(wxNotebook_GetImageList, 1897).
-define(wxNotebook_GetPageImage, 1898).
-define(wxNotebook_GetRowCount, 1899).
-define(wxNotebook_GetThemeBackgroundColour, 1900).
-define(wxNotebook_SetImageList, 1901).
-define(wxNotebook_SetPadding, 1902).
-define(wxNotebook_SetPageSize, 1903).
-define(wxNotebook_SetPageImage, 1904).
-define(wxChoicebook_new_0, 1905).
-define(wxChoicebook_new_3, 1906).
-define(wxChoicebook_AddPage, 1907).
-define(wxChoicebook_AdvanceSelection, 1908).
-define(wxChoicebook_AssignImageList, 1909).
-define(wxChoicebook_Create, 1910).
-define(wxChoicebook_DeleteAllPages, 1911).
-define(wxChoicebook_GetCurrentPage, 1912).
-define(wxChoicebook_GetImageList, 1913).
-define(wxChoicebook_GetPage, 1914).
-define(wxChoicebook_GetPageCount, 1915).
-define(wxChoicebook_GetPageImage, 1916).
-define(wxChoicebook_GetPageText, 1917).
-define(wxChoicebook_GetSelection, 1918).
-define(wxChoicebook_HitTest, 1919).
-define(wxChoicebook_InsertPage, 1920).
-define(wxChoicebook_SetImageList, 1921).
-define(wxChoicebook_SetPageSize, 1922).
-define(wxChoicebook_SetPageImage, 1923).
-define(wxChoicebook_SetPageText, 1924).
-define(wxChoicebook_SetSelection, 1925).
-define(wxChoicebook_ChangeSelection, 1926).
-define(wxChoicebook_destroy, 1927).
-define(wxToolbook_new_0, 1928).
-define(wxToolbook_new_3, 1929).
-define(wxToolbook_AddPage, 1930).
-define(wxToolbook_AdvanceSelection, 1931).
-define(wxToolbook_AssignImageList, 1932).
-define(wxToolbook_Create, 1933).
-define(wxToolbook_DeleteAllPages, 1934).
-define(wxToolbook_GetCurrentPage, 1935).
-define(wxToolbook_GetImageList, 1936).
-define(wxToolbook_GetPage, 1937).
-define(wxToolbook_GetPageCount, 1938).
-define(wxToolbook_GetPageImage, 1939).
-define(wxToolbook_GetPageText, 1940).
-define(wxToolbook_GetSelection, 1941).
-define(wxToolbook_HitTest, 1942).
-define(wxToolbook_InsertPage, 1943).
-define(wxToolbook_SetImageList, 1944).
-define(wxToolbook_SetPageSize, 1945).
-define(wxToolbook_SetPageImage, 1946).
-define(wxToolbook_SetPageText, 1947).
-define(wxToolbook_SetSelection, 1948).
-define(wxToolbook_ChangeSelection, 1949).
-define(wxToolbook_destroy, 1950).
-define(wxListbook_new_0, 1951).
-define(wxListbook_new_3, 1952).
-define(wxListbook_AddPage, 1953).
-define(wxListbook_AdvanceSelection, 1954).
-define(wxListbook_AssignImageList, 1955).
-define(wxListbook_Create, 1956).
-define(wxListbook_DeleteAllPages, 1957).
-define(wxListbook_GetCurrentPage, 1958).
-define(wxListbook_GetImageList, 1959).
-define(wxListbook_GetPage, 1960).
-define(wxListbook_GetPageCount, 1961).
-define(wxListbook_GetPageImage, 1962).
-define(wxListbook_GetPageText, 1963).
-define(wxListbook_GetSelection, 1964).
-define(wxListbook_HitTest, 1965).
-define(wxListbook_InsertPage, 1966).
-define(wxListbook_SetImageList, 1967).
-define(wxListbook_SetPageSize, 1968).
-define(wxListbook_SetPageImage, 1969).
-define(wxListbook_SetPageText, 1970).
-define(wxListbook_SetSelection, 1971).
-define(wxListbook_ChangeSelection, 1972).
-define(wxListbook_destroy, 1973).
-define(wxTreebook_new_0, 1974).
-define(wxTreebook_new_3, 1975).
-define(wxTreebook_destruct, 1976).
-define(wxTreebook_AddPage, 1977).
-define(wxTreebook_AdvanceSelection, 1978).
-define(wxTreebook_AssignImageList, 1979).
-define(wxTreebook_Create, 1980).
-define(wxTreebook_DeleteAllPages, 1981).
-define(wxTreebook_GetCurrentPage, 1982).
-define(wxTreebook_GetImageList, 1983).
-define(wxTreebook_GetPage, 1984).
-define(wxTreebook_GetPageCount, 1985).
-define(wxTreebook_GetPageImage, 1986).
-define(wxTreebook_GetPageText, 1987).
-define(wxTreebook_GetSelection, 1988).
-define(wxTreebook_ExpandNode, 1989).
-define(wxTreebook_IsNodeExpanded, 1990).
-define(wxTreebook_HitTest, 1991).
-define(wxTreebook_InsertPage, 1992).
-define(wxTreebook_InsertSubPage, 1993).
-define(wxTreebook_SetImageList, 1994).
-define(wxTreebook_SetPageSize, 1995).
-define(wxTreebook_SetPageImage, 1996).
-define(wxTreebook_SetPageText, 1997).
-define(wxTreebook_SetSelection, 1998).
-define(wxTreebook_ChangeSelection, 1999).
-define(wxTreeCtrl_new_0, 2000).
-define(wxTreeCtrl_new_2, 2001).
-define(wxTreeCtrl_destruct, 2002).
-define(wxTreeCtrl_AddRoot, 2003).
-define(wxTreeCtrl_AppendItem, 2004).
-define(wxTreeCtrl_AssignImageList, 2005).
-define(wxTreeCtrl_AssignStateImageList, 2006).
-define(wxTreeCtrl_Collapse, 2007).
-define(wxTreeCtrl_CollapseAndReset, 2008).
-define(wxTreeCtrl_Create, 2009).
-define(wxTreeCtrl_Delete, 2010).
-define(wxTreeCtrl_DeleteAllItems, 2011).
-define(wxTreeCtrl_DeleteChildren, 2012).
-define(wxTreeCtrl_EditLabel, 2013).
-define(wxTreeCtrl_EnsureVisible, 2014).
-define(wxTreeCtrl_Expand, 2015).
-define(wxTreeCtrl_GetBoundingRect, 2016).
-define(wxTreeCtrl_GetChildrenCount, 2017).
-define(wxTreeCtrl_GetCount, 2018).
-define(wxTreeCtrl_GetEditControl, 2019).
-define(wxTreeCtrl_GetFirstChild, 2020).
-define(wxTreeCtrl_GetNextChild, 2021).
-define(wxTreeCtrl_GetFirstVisibleItem, 2022).
-define(wxTreeCtrl_GetImageList, 2023).
-define(wxTreeCtrl_GetIndent, 2024).
-define(wxTreeCtrl_GetItemBackgroundColour, 2025).
-define(wxTreeCtrl_GetItemData, 2026).
-define(wxTreeCtrl_GetItemFont, 2027).
-define(wxTreeCtrl_GetItemImage, 2028).
-define(wxTreeCtrl_GetItemText, 2029).
-define(wxTreeCtrl_GetItemTextColour, 2030).
-define(wxTreeCtrl_GetLastChild, 2031).
-define(wxTreeCtrl_GetNextSibling, 2032).
-define(wxTreeCtrl_GetNextVisible, 2033).
-define(wxTreeCtrl_GetItemParent, 2034).
-define(wxTreeCtrl_GetPrevSibling, 2035).
-define(wxTreeCtrl_GetPrevVisible, 2036).
-define(wxTreeCtrl_GetRootItem, 2037).
-define(wxTreeCtrl_GetSelection, 2038).
-define(wxTreeCtrl_GetSelections, 2039).
-define(wxTreeCtrl_GetStateImageList, 2040).
-define(wxTreeCtrl_HitTest, 2041).
-define(wxTreeCtrl_InsertItem, 2042).
-define(wxTreeCtrl_IsBold, 2044).
-define(wxTreeCtrl_IsExpanded, 2045).
-define(wxTreeCtrl_IsSelected, 2046).
-define(wxTreeCtrl_IsVisible, 2047).
-define(wxTreeCtrl_ItemHasChildren, 2048).
-define(wxTreeCtrl_IsTreeItemIdOk, 2049).
-define(wxTreeCtrl_PrependItem, 2050).
-define(wxTreeCtrl_ScrollTo, 2051).
-define(wxTreeCtrl_SelectItem, 2052).
-define(wxTreeCtrl_SetIndent, 2053).
-define(wxTreeCtrl_SetImageList, 2054).
-define(wxTreeCtrl_SetItemBackgroundColour, 2055).
-define(wxTreeCtrl_SetItemBold, 2056).
-define(wxTreeCtrl_SetItemData, 2057).
-define(wxTreeCtrl_SetItemDropHighlight, 2058).
-define(wxTreeCtrl_SetItemFont, 2059).
-define(wxTreeCtrl_SetItemHasChildren, 2060).
-define(wxTreeCtrl_SetItemImage, 2061).
-define(wxTreeCtrl_SetItemText, 2062).
-define(wxTreeCtrl_SetItemTextColour, 2063).
-define(wxTreeCtrl_SetStateImageList, 2064).
-define(wxTreeCtrl_SetWindowStyle, 2065).
-define(wxTreeCtrl_SortChildren, 2066).
-define(wxTreeCtrl_Toggle, 2067).
-define(wxTreeCtrl_ToggleItemSelection, 2068).
-define(wxTreeCtrl_Unselect, 2069).
-define(wxTreeCtrl_UnselectAll, 2070).
-define(wxTreeCtrl_UnselectItem, 2071).
-define(wxScrollBar_new_0, 2072).
-define(wxScrollBar_new_3, 2073).
-define(wxScrollBar_destruct, 2074).
-define(wxScrollBar_Create, 2075).
-define(wxScrollBar_GetRange, 2076).
-define(wxScrollBar_GetPageSize, 2077).
-define(wxScrollBar_GetThumbPosition, 2078).
-define(wxScrollBar_GetThumbSize, 2079).
-define(wxScrollBar_SetThumbPosition, 2080).
-define(wxScrollBar_SetScrollbar, 2081).
-define(wxSpinButton_new_0, 2082).
-define(wxSpinButton_new_2, 2083).
-define(wxSpinButton_destruct, 2084).
-define(wxSpinButton_Create, 2085).
-define(wxSpinButton_GetMax, 2086).
-define(wxSpinButton_GetMin, 2087).
-define(wxSpinButton_GetValue, 2088).
-define(wxSpinButton_SetRange, 2089).
-define(wxSpinButton_SetValue, 2090).
-define(wxSpinCtrl_new_0, 2091).
-define(wxSpinCtrl_new_2, 2092).
-define(wxSpinCtrl_Create, 2093).
-define(wxSpinCtrl_SetValue_1_1, 2094).
-define(wxSpinCtrl_SetValue_1_0, 2095).
-define(wxSpinCtrl_GetValue, 2096).
-define(wxSpinCtrl_SetRange, 2097).
-define(wxSpinCtrl_SetSelection, 2098).
-define(wxSpinCtrl_GetMin, 2099).
-define(wxSpinCtrl_GetMax, 2100).
-define(wxSpinCtrl_destroy, 2101).
-define(wxStaticText_new_0, 2102).
-define(wxStaticText_new_4, 2103).
-define(wxStaticText_Create, 2104).
-define(wxStaticText_GetLabel, 2105).
-define(wxStaticText_SetLabel, 2106).
-define(wxStaticText_Wrap, 2107).
-define(wxStaticText_destroy, 2108).
-define(wxStaticBitmap_new_0, 2109).
-define(wxStaticBitmap_new_4, 2110).
-define(wxStaticBitmap_Create, 2111).
-define(wxStaticBitmap_GetBitmap, 2112).
-define(wxStaticBitmap_SetBitmap, 2113).
-define(wxStaticBitmap_destroy, 2114).
-define(wxRadioBox_new, 2115).
-define(wxRadioBox_destruct, 2116).
-define(wxRadioBox_Create, 2117).
-define(wxRadioBox_Enable_1, 2118).
-define(wxRadioBox_Enable_2, 2119).
-define(wxRadioBox_GetSelection, 2120).
-define(wxRadioBox_GetString, 2121).
-define(wxRadioBox_SetSelection, 2122).
-define(wxRadioBox_Show, 2123).
-define(wxRadioBox_GetColumnCount, 2124).
-define(wxRadioBox_GetItemHelpText, 2125).
-define(wxRadioBox_GetItemToolTip, 2126).
-define(wxRadioBox_GetItemFromPoint, 2127).
-define(wxRadioBox_GetRowCount, 2128).
-define(wxRadioBox_IsItemEnabled, 2129).
-define(wxRadioBox_IsItemShown, 2130).
-define(wxRadioBox_SetItemHelpText, 2131).
-define(wxRadioBox_SetItemToolTip, 2132).
-define(wxRadioButton_new_0, 2133).
-define(wxRadioButton_new_4, 2134).
-define(wxRadioButton_destruct, 2135).
-define(wxRadioButton_Create, 2136).
-define(wxRadioButton_GetValue, 2137).
-define(wxRadioButton_SetValue, 2138).
-define(wxSlider_new_0, 2139).
-define(wxSlider_new_6, 2140).
-define(wxSlider_destruct, 2141).
-define(wxSlider_Create, 2142).
-define(wxSlider_GetLineSize, 2143).
-define(wxSlider_GetMax, 2144).
-define(wxSlider_GetMin, 2145).
-define(wxSlider_GetPageSize, 2146).
-define(wxSlider_GetThumbLength, 2147).
-define(wxSlider_GetValue, 2148).
-define(wxSlider_SetLineSize, 2149).
-define(wxSlider_SetPageSize, 2150).
-define(wxSlider_SetRange, 2151).
-define(wxSlider_SetThumbLength, 2152).
-define(wxSlider_SetValue, 2153).
-define(wxDialog_new_0, 2154).
-define(wxDialog_new_4, 2155).
-define(wxDialog_destruct, 2156).
-define(wxDialog_Create, 2157).
-define(wxDialog_CreateButtonSizer, 2158).
-define(wxDialog_CreateStdDialogButtonSizer, 2159).
-define(wxDialog_EndModal, 2160).
-define(wxDialog_GetAffirmativeId, 2161).
-define(wxDialog_GetReturnCode, 2162).
-define(wxDialog_IsModal, 2163).
-define(wxDialog_SetAffirmativeId, 2164).
-define(wxDialog_SetReturnCode, 2165).
-define(wxDialog_Show, 2166).
-define(wxDialog_ShowModal, 2167).
-define(wxColourDialog_new_0, 2168).
-define(wxColourDialog_new_2, 2169).
-define(wxColourDialog_destruct, 2170).
-define(wxColourDialog_Create, 2171).
-define(wxColourDialog_GetColourData, 2172).
-define(wxColourData_new, 2173).
-define(wxColourData_destruct, 2174).
-define(wxColourData_GetChooseFull, 2175).
-define(wxColourData_GetColour, 2176).
-define(wxColourData_GetCustomColour, 2177).
-define(wxColourData_SetChooseFull, 2178).
-define(wxColourData_SetColour, 2179).
-define(wxColourData_SetCustomColour, 2180).
-define(wxPalette_new_0, 2181).
-define(wxPalette_new_1, 2182).
-define(wxPalette_new_4, 2183).
-define(wxPalette_destruct, 2184).
-define(wxPalette_Create, 2185).
-define(wxPalette_GetColoursCount, 2186).
-define(wxPalette_GetPixel, 2187).
-define(wxPalette_GetRGB, 2188).
-define(wxPalette_IsOk, 2189).
-define(wxDirDialog_new, 2190).
-define(wxDirDialog_destruct, 2191).
-define(wxDirDialog_GetPath, 2192).
-define(wxDirDialog_GetMessage, 2193).
-define(wxDirDialog_SetMessage, 2194).
-define(wxDirDialog_SetPath, 2195).
-define(wxFileDialog_new, 2196).
-define(wxFileDialog_destruct, 2197).
-define(wxFileDialog_GetDirectory, 2198).
-define(wxFileDialog_GetFilename, 2199).
-define(wxFileDialog_GetFilenames, 2200).
-define(wxFileDialog_GetFilterIndex, 2201).
-define(wxFileDialog_GetMessage, 2202).
-define(wxFileDialog_GetPath, 2203).
-define(wxFileDialog_GetPaths, 2204).
-define(wxFileDialog_GetWildcard, 2205).
-define(wxFileDialog_SetDirectory, 2206).
-define(wxFileDialog_SetFilename, 2207).
-define(wxFileDialog_SetFilterIndex, 2208).
-define(wxFileDialog_SetMessage, 2209).
-define(wxFileDialog_SetPath, 2210).
-define(wxFileDialog_SetWildcard, 2211).
-define(wxPickerBase_SetInternalMargin, 2212).
-define(wxPickerBase_GetInternalMargin, 2213).
-define(wxPickerBase_SetTextCtrlProportion, 2214).
-define(wxPickerBase_SetPickerCtrlProportion, 2215).
-define(wxPickerBase_GetTextCtrlProportion, 2216).
-define(wxPickerBase_GetPickerCtrlProportion, 2217).
-define(wxPickerBase_HasTextCtrl, 2218).
-define(wxPickerBase_GetTextCtrl, 2219).
-define(wxPickerBase_IsTextCtrlGrowable, 2220).
-define(wxPickerBase_SetPickerCtrlGrowable, 2221).
-define(wxPickerBase_SetTextCtrlGrowable, 2222).
-define(wxPickerBase_IsPickerCtrlGrowable, 2223).
-define(wxFilePickerCtrl_new_0, 2224).
-define(wxFilePickerCtrl_new_3, 2225).
-define(wxFilePickerCtrl_Create, 2226).
-define(wxFilePickerCtrl_GetPath, 2227).
-define(wxFilePickerCtrl_SetPath, 2228).
-define(wxFilePickerCtrl_destroy, 2229).
-define(wxDirPickerCtrl_new_0, 2230).
-define(wxDirPickerCtrl_new_3, 2231).
-define(wxDirPickerCtrl_Create, 2232).
-define(wxDirPickerCtrl_GetPath, 2233).
-define(wxDirPickerCtrl_SetPath, 2234).
-define(wxDirPickerCtrl_destroy, 2235).
-define(wxColourPickerCtrl_new_0, 2236).
-define(wxColourPickerCtrl_new_3, 2237).
-define(wxColourPickerCtrl_Create, 2238).
-define(wxColourPickerCtrl_GetColour, 2239).
-define(wxColourPickerCtrl_SetColour_1_1, 2240).
-define(wxColourPickerCtrl_SetColour_1_0, 2241).
-define(wxColourPickerCtrl_destroy, 2242).
-define(wxDatePickerCtrl_new_0, 2243).
-define(wxDatePickerCtrl_new_3, 2244).
-define(wxDatePickerCtrl_GetRange, 2245).
-define(wxDatePickerCtrl_GetValue, 2246).
-define(wxDatePickerCtrl_SetRange, 2247).
-define(wxDatePickerCtrl_SetValue, 2248).
-define(wxDatePickerCtrl_destroy, 2249).
-define(wxFontPickerCtrl_new_0, 2250).
-define(wxFontPickerCtrl_new_3, 2251).
-define(wxFontPickerCtrl_Create, 2252).
-define(wxFontPickerCtrl_GetSelectedFont, 2253).
-define(wxFontPickerCtrl_SetSelectedFont, 2254).
-define(wxFontPickerCtrl_GetMaxPointSize, 2255).
-define(wxFontPickerCtrl_SetMaxPointSize, 2256).
-define(wxFontPickerCtrl_destroy, 2257).
-define(wxFindReplaceDialog_new_0, 2258).
-define(wxFindReplaceDialog_new_4, 2259).
-define(wxFindReplaceDialog_destruct, 2260).
-define(wxFindReplaceDialog_Create, 2261).
-define(wxFindReplaceDialog_GetData, 2262).
-define(wxFindReplaceData_new, 2263).
-define(wxFindReplaceData_GetFindString, 2264).
-define(wxFindReplaceData_GetReplaceString, 2265).
-define(wxFindReplaceData_GetFlags, 2266).
-define(wxFindReplaceData_SetFlags, 2267).
-define(wxFindReplaceData_SetFindString, 2268).
-define(wxFindReplaceData_SetReplaceString, 2269).
-define(wxFindReplaceData_destroy, 2270).
-define(wxMultiChoiceDialog_new, 2272).
-define(wxMultiChoiceDialog_GetSelections, 2273).
-define(wxMultiChoiceDialog_SetSelections, 2274).
-define(wxMultiChoiceDialog_destroy, 2275).
-define(wxSingleChoiceDialog_new, 2277).
-define(wxSingleChoiceDialog_GetSelection, 2278).
-define(wxSingleChoiceDialog_GetStringSelection, 2279).
-define(wxSingleChoiceDialog_SetSelection, 2280).
-define(wxSingleChoiceDialog_destroy, 2281).
-define(wxTextEntryDialog_new_0, 2282).
-define(wxTextEntryDialog_new_3, 2283).
-define(wxTextEntryDialog_destruct, 2284).
-define(wxTextEntryDialog_GetValue, 2285).
-define(wxTextEntryDialog_SetValue, 2286).
-define(wxPasswordEntryDialog_new, 2287).
-define(wxPasswordEntryDialog_destroy, 2288).
-define(wxFontData_new_0, 2289).
-define(wxFontData_new_1, 2290).
-define(wxFontData_EnableEffects, 2291).
-define(wxFontData_GetAllowSymbols, 2292).
-define(wxFontData_GetColour, 2293).
-define(wxFontData_GetChosenFont, 2294).
-define(wxFontData_GetEnableEffects, 2295).
-define(wxFontData_GetInitialFont, 2296).
-define(wxFontData_GetShowHelp, 2297).
-define(wxFontData_SetAllowSymbols, 2298).
-define(wxFontData_SetChosenFont, 2299).
-define(wxFontData_SetColour, 2300).
-define(wxFontData_SetInitialFont, 2301).
-define(wxFontData_SetRange, 2302).
-define(wxFontData_SetShowHelp, 2303).
-define(wxFontData_destroy, 2304).
-define(wxFontDialog_new_0, 2305).
-define(wxFontDialog_new_2, 2307).
-define(wxFontDialog_Create, 2309).
-define(wxFontDialog_GetFontData, 2310).
-define(wxFontDialog_destroy, 2312).
-define(wxProgressDialog_new, 2313).
-define(wxProgressDialog_Resume, 2314).
-define(wxProgressDialog_Update, 2315).
-define(wxProgressDialog_destroy, 2316).
-define(wxMessageDialog_new, 2317).
-define(wxMessageDialog_destroy, 2318).
-define(wxPageSetupDialog_new, 2319).
-define(wxPageSetupDialog_destruct, 2320).
-define(wxPageSetupDialog_GetPageSetupData, 2321).
-define(wxPageSetupDialog_ShowModal, 2322).
-define(wxPageSetupDialogData_new_0, 2323).
-define(wxPageSetupDialogData_new_1, 2325).
-define(wxPageSetupDialogData_destruct, 2326).
-define(wxPageSetupDialogData_EnableHelp, 2327).
-define(wxPageSetupDialogData_EnableMargins, 2328).
-define(wxPageSetupDialogData_EnableOrientation, 2329).
-define(wxPageSetupDialogData_EnablePaper, 2330).
-define(wxPageSetupDialogData_EnablePrinter, 2331).
-define(wxPageSetupDialogData_GetDefaultMinMargins, 2332).
-define(wxPageSetupDialogData_GetEnableMargins, 2333).
-define(wxPageSetupDialogData_GetEnableOrientation, 2334).
-define(wxPageSetupDialogData_GetEnablePaper, 2335).
-define(wxPageSetupDialogData_GetEnablePrinter, 2336).
-define(wxPageSetupDialogData_GetEnableHelp, 2337).
-define(wxPageSetupDialogData_GetDefaultInfo, 2338).
-define(wxPageSetupDialogData_GetMarginTopLeft, 2339).
-define(wxPageSetupDialogData_GetMarginBottomRight, 2340).
-define(wxPageSetupDialogData_GetMinMarginTopLeft, 2341).
-define(wxPageSetupDialogData_GetMinMarginBottomRight, 2342).
-define(wxPageSetupDialogData_GetPaperId, 2343).
-define(wxPageSetupDialogData_GetPaperSize, 2344).
-define(wxPageSetupDialogData_GetPrintData, 2346).
-define(wxPageSetupDialogData_IsOk, 2347).
-define(wxPageSetupDialogData_SetDefaultInfo, 2348).
-define(wxPageSetupDialogData_SetDefaultMinMargins, 2349).
-define(wxPageSetupDialogData_SetMarginTopLeft, 2350).
-define(wxPageSetupDialogData_SetMarginBottomRight, 2351).
-define(wxPageSetupDialogData_SetMinMarginTopLeft, 2352).
-define(wxPageSetupDialogData_SetMinMarginBottomRight, 2353).
-define(wxPageSetupDialogData_SetPaperId, 2354).
-define(wxPageSetupDialogData_SetPaperSize, 2355).
-define(wxPageSetupDialogData_SetPrintData, 2356).
-define(wxPrintDialog_new_2_0, 2357).
-define(wxPrintDialog_new_2_1, 2358).
-define(wxPrintDialog_destruct, 2359).
-define(wxPrintDialog_GetPrintDialogData, 2360).
-define(wxPrintDialog_GetPrintDC, 2361).
-define(wxPrintDialogData_new_0, 2362).
-define(wxPrintDialogData_new_1, 2363).
-define(wxPrintDialogData_destruct, 2365).
-define(wxPrintDialogData_EnableHelp, 2366).
-define(wxPrintDialogData_EnablePageNumbers, 2367).
-define(wxPrintDialogData_EnablePrintToFile, 2368).
-define(wxPrintDialogData_EnableSelection, 2369).
-define(wxPrintDialogData_GetAllPages, 2370).
-define(wxPrintDialogData_GetCollate, 2371).
-define(wxPrintDialogData_GetFromPage, 2372).
-define(wxPrintDialogData_GetMaxPage, 2373).
-define(wxPrintDialogData_GetMinPage, 2374).
-define(wxPrintDialogData_GetNoCopies, 2375).
-define(wxPrintDialogData_GetPrintData, 2376).
-define(wxPrintDialogData_GetPrintToFile, 2377).
-define(wxPrintDialogData_GetSelection, 2378).
-define(wxPrintDialogData_GetToPage, 2379).
-define(wxPrintDialogData_IsOk, 2380).
-define(wxPrintDialogData_SetCollate, 2381).
-define(wxPrintDialogData_SetFromPage, 2382).
-define(wxPrintDialogData_SetMaxPage, 2383).
-define(wxPrintDialogData_SetMinPage, 2384).
-define(wxPrintDialogData_SetNoCopies, 2385).
-define(wxPrintDialogData_SetPrintData, 2386).
-define(wxPrintDialogData_SetPrintToFile, 2387).
-define(wxPrintDialogData_SetSelection, 2388).
-define(wxPrintDialogData_SetToPage, 2389).
-define(wxPrintData_new_0, 2390).
-define(wxPrintData_new_1, 2391).
-define(wxPrintData_destruct, 2392).
-define(wxPrintData_GetCollate, 2393).
-define(wxPrintData_GetBin, 2394).
-define(wxPrintData_GetColour, 2395).
-define(wxPrintData_GetDuplex, 2396).
-define(wxPrintData_GetNoCopies, 2397).
-define(wxPrintData_GetOrientation, 2398).
-define(wxPrintData_GetPaperId, 2399).
-define(wxPrintData_GetPrinterName, 2400).
-define(wxPrintData_GetQuality, 2401).
-define(wxPrintData_IsOk, 2402).
-define(wxPrintData_SetBin, 2403).
-define(wxPrintData_SetCollate, 2404).
-define(wxPrintData_SetColour, 2405).
-define(wxPrintData_SetDuplex, 2406).
-define(wxPrintData_SetNoCopies, 2407).
-define(wxPrintData_SetOrientation, 2408).
-define(wxPrintData_SetPaperId, 2409).
-define(wxPrintData_SetPrinterName, 2410).
-define(wxPrintData_SetQuality, 2411).
-define(wxPrintPreview_new_2, 2412).
-define(wxPrintPreview_new_3, 2413).
-define(wxPrintPreview_destruct, 2414).
-define(wxPrintPreview_GetCanvas, 2415).
-define(wxPrintPreview_GetCurrentPage, 2416).
-define(wxPrintPreview_GetFrame, 2417).
-define(wxPrintPreview_GetMaxPage, 2418).
-define(wxPrintPreview_GetMinPage, 2419).
-define(wxPrintPreview_GetPrintout, 2420).
-define(wxPrintPreview_GetPrintoutForPrinting, 2421).
-define(wxPrintPreview_IsOk, 2422).
-define(wxPrintPreview_PaintPage, 2423).
-define(wxPrintPreview_Print, 2424).
-define(wxPrintPreview_RenderPage, 2425).
-define(wxPrintPreview_SetCanvas, 2426).
-define(wxPrintPreview_SetCurrentPage, 2427).
-define(wxPrintPreview_SetFrame, 2428).
-define(wxPrintPreview_SetPrintout, 2429).
-define(wxPrintPreview_SetZoom, 2430).
-define(wxPreviewFrame_new, 2431).
-define(wxPreviewFrame_destruct, 2432).
-define(wxPreviewFrame_CreateControlBar, 2433).
-define(wxPreviewFrame_CreateCanvas, 2434).
-define(wxPreviewFrame_Initialize, 2435).
-define(wxPreviewFrame_OnCloseWindow, 2436).
-define(wxPreviewControlBar_new, 2437).
-define(wxPreviewControlBar_destruct, 2438).
-define(wxPreviewControlBar_CreateButtons, 2439).
-define(wxPreviewControlBar_GetPrintPreview, 2440).
-define(wxPreviewControlBar_GetZoomControl, 2441).
-define(wxPreviewControlBar_SetZoomControl, 2442).
-define(wxPrinter_new, 2443).
-define(wxPrinter_CreateAbortWindow, 2444).
-define(wxPrinter_GetAbort, 2445).
-define(wxPrinter_GetLastError, 2446).
-define(wxPrinter_GetPrintDialogData, 2447).
-define(wxPrinter_Print, 2448).
-define(wxPrinter_PrintDialog, 2449).
-define(wxPrinter_ReportError, 2450).
-define(wxPrinter_Setup, 2451).
-define(wxPrinter_destroy, 2452).
-define(wxXmlResource_new_2, 2453).
-define(wxXmlResource_new_1, 2454).
-define(wxXmlResource_destruct, 2455).
-define(wxXmlResource_AttachUnknownControl, 2456).
-define(wxXmlResource_ClearHandlers, 2457).
-define(wxXmlResource_CompareVersion, 2458).
-define(wxXmlResource_Get, 2459).
-define(wxXmlResource_GetFlags, 2460).
-define(wxXmlResource_GetVersion, 2461).
-define(wxXmlResource_GetXRCID, 2462).
-define(wxXmlResource_InitAllHandlers, 2463).
-define(wxXmlResource_Load, 2464).
-define(wxXmlResource_LoadBitmap, 2465).
-define(wxXmlResource_LoadDialog_2, 2466).
-define(wxXmlResource_LoadDialog_3, 2467).
-define(wxXmlResource_LoadFrame_2, 2468).
-define(wxXmlResource_LoadFrame_3, 2469).
-define(wxXmlResource_LoadIcon, 2470).
-define(wxXmlResource_LoadMenu, 2471).
-define(wxXmlResource_LoadMenuBar_2, 2472).
-define(wxXmlResource_LoadMenuBar_1, 2473).
-define(wxXmlResource_LoadPanel_2, 2474).
-define(wxXmlResource_LoadPanel_3, 2475).
-define(wxXmlResource_LoadToolBar, 2476).
-define(wxXmlResource_Set, 2477).
-define(wxXmlResource_SetFlags, 2478).
-define(wxXmlResource_Unload, 2479).
-define(wxXmlResource_xrcctrl, 2480).
-define(wxHtmlEasyPrinting_new, 2481).
-define(wxHtmlEasyPrinting_GetPrintData, 2482).
-define(wxHtmlEasyPrinting_GetPageSetupData, 2483).
-define(wxHtmlEasyPrinting_PreviewFile, 2484).
-define(wxHtmlEasyPrinting_PreviewText, 2485).
-define(wxHtmlEasyPrinting_PrintFile, 2486).
-define(wxHtmlEasyPrinting_PrintText, 2487).
-define(wxHtmlEasyPrinting_PageSetup, 2488).
-define(wxHtmlEasyPrinting_SetFonts, 2489).
-define(wxHtmlEasyPrinting_SetHeader, 2490).
-define(wxHtmlEasyPrinting_SetFooter, 2491).
-define(wxHtmlEasyPrinting_destroy, 2492).
-define(wxGLCanvas_new, 2493).
-define(wxGLCanvas_SetCurrent, 2494).
-define(wxGLCanvas_CreateSurface, 2495).
-define(wxGLCanvas_IsDisplaySupported, 2496).
-define(wxGLCanvas_SwapBuffers, 2497).
-define(wxGLCanvas_destroy, 2498).
-define(wxGLContext_new, 2499).
-define(wxGLContext_SetCurrent, 2500).
-define(wxGLContext_IsOK, 2501).
-define(wxGLContext_destroy, 2502).
-define(wxAuiManager_new, 2503).
-define(wxAuiManager_destruct, 2504).
-define(wxAuiManager_AddPane_2_1, 2505).
-define(wxAuiManager_AddPane_2_0, 2506).
-define(wxAuiManager_AddPane_3, 2507).
-define(wxAuiManager_DetachPane, 2508).
-define(wxAuiManager_GetAllPanes, 2509).
-define(wxAuiManager_GetArtProvider, 2510).
-define(wxAuiManager_GetDockSizeConstraint, 2511).
-define(wxAuiManager_GetFlags, 2512).
-define(wxAuiManager_GetManagedWindow, 2513).
-define(wxAuiManager_GetManager, 2514).
-define(wxAuiManager_GetPane_1_1, 2515).
-define(wxAuiManager_GetPane_1_0, 2516).
-define(wxAuiManager_HideHint, 2517).
-define(wxAuiManager_InsertPane, 2518).
-define(wxAuiManager_LoadPaneInfo, 2519).
-define(wxAuiManager_LoadPerspective, 2520).
-define(wxAuiManager_SavePaneInfo, 2521).
-define(wxAuiManager_SavePerspective, 2522).
-define(wxAuiManager_SetArtProvider, 2523).
-define(wxAuiManager_SetDockSizeConstraint, 2524).
-define(wxAuiManager_SetFlags, 2525).
-define(wxAuiManager_SetManagedWindow, 2526).
-define(wxAuiManager_ShowHint, 2527).
-define(wxAuiManager_UnInit, 2528).
-define(wxAuiManager_Update, 2529).
-define(wxAuiPaneInfo_new_0, 2530).
-define(wxAuiPaneInfo_new_1, 2531).
-define(wxAuiPaneInfo_BestSize_1, 2532).
-define(wxAuiPaneInfo_BestSize_2, 2533).
-define(wxAuiPaneInfo_Bottom, 2534).
-define(wxAuiPaneInfo_BottomDockable, 2535).
-define(wxAuiPaneInfo_Caption, 2536).
-define(wxAuiPaneInfo_CaptionVisible, 2537).
-define(wxAuiPaneInfo_Centre, 2538).
-define(wxAuiPaneInfo_CentrePane, 2539).
-define(wxAuiPaneInfo_CloseButton, 2540).
-define(wxAuiPaneInfo_DefaultPane, 2541).
-define(wxAuiPaneInfo_DestroyOnClose, 2542).
-define(wxAuiPaneInfo_Direction, 2543).
-define(wxAuiPaneInfo_Dock, 2544).
-define(wxAuiPaneInfo_Dockable, 2545).
-define(wxAuiPaneInfo_Fixed, 2546).
-define(wxAuiPaneInfo_Float, 2547).
-define(wxAuiPaneInfo_Floatable, 2548).
-define(wxAuiPaneInfo_FloatingPosition_1, 2549).
-define(wxAuiPaneInfo_FloatingPosition_2, 2550).
-define(wxAuiPaneInfo_FloatingSize_1, 2551).
-define(wxAuiPaneInfo_FloatingSize_2, 2552).
-define(wxAuiPaneInfo_Gripper, 2553).
-define(wxAuiPaneInfo_GripperTop, 2554).
-define(wxAuiPaneInfo_HasBorder, 2555).
-define(wxAuiPaneInfo_HasCaption, 2556).
-define(wxAuiPaneInfo_HasCloseButton, 2557).
-define(wxAuiPaneInfo_HasFlag, 2558).
-define(wxAuiPaneInfo_HasGripper, 2559).
-define(wxAuiPaneInfo_HasGripperTop, 2560).
-define(wxAuiPaneInfo_HasMaximizeButton, 2561).
-define(wxAuiPaneInfo_HasMinimizeButton, 2562).
-define(wxAuiPaneInfo_HasPinButton, 2563).
-define(wxAuiPaneInfo_Hide, 2564).
-define(wxAuiPaneInfo_IsBottomDockable, 2565).
-define(wxAuiPaneInfo_IsDocked, 2566).
-define(wxAuiPaneInfo_IsFixed, 2567).
-define(wxAuiPaneInfo_IsFloatable, 2568).
-define(wxAuiPaneInfo_IsFloating, 2569).
-define(wxAuiPaneInfo_IsLeftDockable, 2570).
-define(wxAuiPaneInfo_IsMovable, 2571).
-define(wxAuiPaneInfo_IsOk, 2572).
-define(wxAuiPaneInfo_IsResizable, 2573).
-define(wxAuiPaneInfo_IsRightDockable, 2574).
-define(wxAuiPaneInfo_IsShown, 2575).
-define(wxAuiPaneInfo_IsToolbar, 2576).
-define(wxAuiPaneInfo_IsTopDockable, 2577).
-define(wxAuiPaneInfo_Layer, 2578).
-define(wxAuiPaneInfo_Left, 2579).
-define(wxAuiPaneInfo_LeftDockable, 2580).
-define(wxAuiPaneInfo_MaxSize_1, 2581).
-define(wxAuiPaneInfo_MaxSize_2, 2582).
-define(wxAuiPaneInfo_MaximizeButton, 2583).
-define(wxAuiPaneInfo_MinSize_1, 2584).
-define(wxAuiPaneInfo_MinSize_2, 2585).
-define(wxAuiPaneInfo_MinimizeButton, 2586).
-define(wxAuiPaneInfo_Movable, 2587).
-define(wxAuiPaneInfo_Name, 2588).
-define(wxAuiPaneInfo_PaneBorder, 2589).
-define(wxAuiPaneInfo_PinButton, 2590).
-define(wxAuiPaneInfo_Position, 2591).
-define(wxAuiPaneInfo_Resizable, 2592).
-define(wxAuiPaneInfo_Right, 2593).
-define(wxAuiPaneInfo_RightDockable, 2594).
-define(wxAuiPaneInfo_Row, 2595).
-define(wxAuiPaneInfo_SafeSet, 2596).
-define(wxAuiPaneInfo_SetFlag, 2597).
-define(wxAuiPaneInfo_Show, 2598).
-define(wxAuiPaneInfo_ToolbarPane, 2599).
-define(wxAuiPaneInfo_Top, 2600).
-define(wxAuiPaneInfo_TopDockable, 2601).
-define(wxAuiPaneInfo_Window, 2602).
-define(wxAuiPaneInfo_GetWindow, 2603).
-define(wxAuiPaneInfo_GetFrame, 2604).
-define(wxAuiPaneInfo_GetDirection, 2605).
-define(wxAuiPaneInfo_GetLayer, 2606).
-define(wxAuiPaneInfo_GetRow, 2607).
-define(wxAuiPaneInfo_GetPosition, 2608).
-define(wxAuiPaneInfo_GetFloatingPosition, 2609).
-define(wxAuiPaneInfo_GetFloatingSize, 2610).
-define(wxAuiPaneInfo_destroy, 2611).
-define(wxAuiNotebook_new_0, 2612).
-define(wxAuiNotebook_new_2, 2613).
-define(wxAuiNotebook_AddPage_3, 2614).
-define(wxAuiNotebook_AddPage_4, 2615).
-define(wxAuiNotebook_Create_2, 2616).
-define(wxAuiNotebook_Create_3, 2617).
-define(wxAuiNotebook_DeletePage, 2618).
-define(wxAuiNotebook_GetArtProvider, 2619).
-define(wxAuiNotebook_GetPage, 2620).
-define(wxAuiNotebook_GetPageBitmap, 2621).
-define(wxAuiNotebook_GetPageCount, 2622).
-define(wxAuiNotebook_GetPageIndex, 2623).
-define(wxAuiNotebook_GetPageText, 2624).
-define(wxAuiNotebook_GetSelection, 2625).
-define(wxAuiNotebook_InsertPage_4, 2626).
-define(wxAuiNotebook_InsertPage_5, 2627).
-define(wxAuiNotebook_RemovePage, 2628).
-define(wxAuiNotebook_SetArtProvider, 2629).
-define(wxAuiNotebook_SetFont, 2630).
-define(wxAuiNotebook_SetPageBitmap, 2631).
-define(wxAuiNotebook_SetPageText, 2632).
-define(wxAuiNotebook_SetSelection, 2633).
-define(wxAuiNotebook_SetTabCtrlHeight, 2634).
-define(wxAuiNotebook_SetUniformBitmapSize, 2635).
-define(wxAuiNotebook_destroy, 2636).
-define(wxAuiTabArt_SetFlags, 2637).
-define(wxAuiTabArt_SetMeasuringFont, 2638).
-define(wxAuiTabArt_SetNormalFont, 2639).
-define(wxAuiTabArt_SetSelectedFont, 2640).
-define(wxAuiTabArt_SetColour, 2641).
-define(wxAuiTabArt_SetActiveColour, 2642).
-define(wxAuiDockArt_GetColour, 2643).
-define(wxAuiDockArt_GetFont, 2644).
-define(wxAuiDockArt_GetMetric, 2645).
-define(wxAuiDockArt_SetColour, 2646).
-define(wxAuiDockArt_SetFont, 2647).
-define(wxAuiDockArt_SetMetric, 2648).
-define(wxAuiSimpleTabArt_new, 2649).
-define(wxAuiSimpleTabArt_destroy, 2650).
-define(wxMDIParentFrame_new_0, 2651).
-define(wxMDIParentFrame_new_4, 2652).
-define(wxMDIParentFrame_destruct, 2653).
-define(wxMDIParentFrame_ActivateNext, 2654).
-define(wxMDIParentFrame_ActivatePrevious, 2655).
-define(wxMDIParentFrame_ArrangeIcons, 2656).
-define(wxMDIParentFrame_Cascade, 2657).
-define(wxMDIParentFrame_Create, 2658).
-define(wxMDIParentFrame_GetActiveChild, 2659).
-define(wxMDIParentFrame_GetClientWindow, 2660).
-define(wxMDIParentFrame_Tile, 2661).
-define(wxMDIChildFrame_new_0, 2662).
-define(wxMDIChildFrame_new_4, 2663).
-define(wxMDIChildFrame_destruct, 2664).
-define(wxMDIChildFrame_Activate, 2665).
-define(wxMDIChildFrame_Create, 2666).
-define(wxMDIChildFrame_Maximize, 2667).
-define(wxMDIChildFrame_Restore, 2668).
-define(wxMDIClientWindow_new, 2669).
-define(wxMDIClientWindow_CreateClient, 2670).
-define(wxMDIClientWindow_destroy, 2671).
-define(wxLayoutAlgorithm_new, 2672).
-define(wxLayoutAlgorithm_destruct, 2673).
-define(wxLayoutAlgorithm_LayoutFrame, 2674).
-define(wxLayoutAlgorithm_LayoutMDIFrame, 2675).
-define(wxLayoutAlgorithm_LayoutWindow, 2676).
-define(wxEvent_GetId, 2677).
-define(wxEvent_GetSkipped, 2678).
-define(wxEvent_GetTimestamp, 2679).
-define(wxEvent_IsCommandEvent, 2680).
-define(wxEvent_ResumePropagation, 2681).
-define(wxEvent_ShouldPropagate, 2682).
-define(wxEvent_Skip, 2683).
-define(wxEvent_StopPropagation, 2684).
-define(wxCommandEvent_getClientData, 2685).
-define(wxCommandEvent_GetExtraLong, 2686).
-define(wxCommandEvent_GetInt, 2687).
-define(wxCommandEvent_GetSelection, 2688).
-define(wxCommandEvent_GetString, 2689).
-define(wxCommandEvent_IsChecked, 2690).
-define(wxCommandEvent_IsSelection, 2691).
-define(wxCommandEvent_SetInt, 2692).
-define(wxCommandEvent_SetString, 2693).
-define(wxScrollEvent_GetOrientation, 2694).
-define(wxScrollEvent_GetPosition, 2695).
-define(wxScrollWinEvent_GetOrientation, 2696).
-define(wxScrollWinEvent_GetPosition, 2697).
-define(wxMouseEvent_AltDown, 2698).
-define(wxMouseEvent_Button, 2699).
-define(wxMouseEvent_ButtonDClick, 2700).
-define(wxMouseEvent_ButtonDown, 2701).
-define(wxMouseEvent_ButtonUp, 2702).
-define(wxMouseEvent_CmdDown, 2703).
-define(wxMouseEvent_ControlDown, 2704).
-define(wxMouseEvent_Dragging, 2705).
-define(wxMouseEvent_Entering, 2706).
-define(wxMouseEvent_GetButton, 2707).
-define(wxMouseEvent_GetPosition, 2708).
-define(wxMouseEvent_GetLogicalPosition, 2710).
-define(wxMouseEvent_GetLinesPerAction, 2711).
-define(wxMouseEvent_GetWheelRotation, 2712).
-define(wxMouseEvent_GetWheelDelta, 2713).
-define(wxMouseEvent_GetX, 2714).
-define(wxMouseEvent_GetY, 2715).
-define(wxMouseEvent_IsButton, 2716).
-define(wxMouseEvent_IsPageScroll, 2717).
-define(wxMouseEvent_Leaving, 2718).
-define(wxMouseEvent_LeftDClick, 2719).
-define(wxMouseEvent_LeftDown, 2720).
-define(wxMouseEvent_LeftIsDown, 2721).
-define(wxMouseEvent_LeftUp, 2722).
-define(wxMouseEvent_MetaDown, 2723).
-define(wxMouseEvent_MiddleDClick, 2724).
-define(wxMouseEvent_MiddleDown, 2725).
-define(wxMouseEvent_MiddleIsDown, 2726).
-define(wxMouseEvent_MiddleUp, 2727).
-define(wxMouseEvent_Moving, 2728).
-define(wxMouseEvent_RightDClick, 2729).
-define(wxMouseEvent_RightDown, 2730).
-define(wxMouseEvent_RightIsDown, 2731).
-define(wxMouseEvent_RightUp, 2732).
-define(wxMouseEvent_ShiftDown, 2733).
-define(wxMouseEvent_GetWheelAxis, 2734).
-define(wxMouseEvent_Aux1DClick, 2735).
-define(wxMouseEvent_Aux1Down, 2736).
-define(wxMouseEvent_Aux1Up, 2737).
-define(wxMouseEvent_Aux2DClick, 2738).
-define(wxMouseEvent_Aux2Down, 2739).
-define(wxMouseEvent_Aux2Up, 2740).
-define(wxSetCursorEvent_GetCursor, 2741).
-define(wxSetCursorEvent_GetX, 2742).
-define(wxSetCursorEvent_GetY, 2743).
-define(wxSetCursorEvent_HasCursor, 2744).
-define(wxSetCursorEvent_SetCursor, 2745).
-define(wxKeyEvent_AltDown, 2746).
-define(wxKeyEvent_CmdDown, 2747).
-define(wxKeyEvent_ControlDown, 2748).
-define(wxKeyEvent_GetKeyCode, 2749).
-define(wxKeyEvent_GetModifiers, 2750).
-define(wxKeyEvent_GetPosition, 2751).
-define(wxKeyEvent_GetRawKeyCode, 2753).
-define(wxKeyEvent_GetRawKeyFlags, 2754).
-define(wxKeyEvent_GetUnicodeKey, 2755).
-define(wxKeyEvent_GetX, 2756).
-define(wxKeyEvent_GetY, 2757).
-define(wxKeyEvent_HasModifiers, 2758).
-define(wxKeyEvent_MetaDown, 2759).
-define(wxKeyEvent_ShiftDown, 2760).
-define(wxSizeEvent_GetSize, 2761).
-define(wxSizeEvent_GetRect, 2762).
-define(wxMoveEvent_GetPosition, 2763).
-define(wxMoveEvent_GetRect, 2764).
-define(wxEraseEvent_GetDC, 2765).
-define(wxFocusEvent_GetWindow, 2766).
-define(wxChildFocusEvent_GetWindow, 2767).
-define(wxMenuEvent_GetMenu, 2768).
-define(wxMenuEvent_GetMenuId, 2769).
-define(wxMenuEvent_IsPopup, 2770).
-define(wxCloseEvent_CanVeto, 2771).
-define(wxCloseEvent_GetLoggingOff, 2772).
-define(wxCloseEvent_SetCanVeto, 2773).
-define(wxCloseEvent_SetLoggingOff, 2774).
-define(wxCloseEvent_Veto, 2775).
-define(wxShowEvent_SetShow, 2776).
-define(wxShowEvent_IsShown, 2777).
-define(wxIconizeEvent_IsIconized, 2778).
-define(wxJoystickEvent_ButtonDown, 2779).
-define(wxJoystickEvent_ButtonIsDown, 2780).
-define(wxJoystickEvent_ButtonUp, 2781).
-define(wxJoystickEvent_GetButtonChange, 2782).
-define(wxJoystickEvent_GetButtonState, 2783).
-define(wxJoystickEvent_GetJoystick, 2784).
-define(wxJoystickEvent_GetPosition, 2785).
-define(wxJoystickEvent_GetZPosition, 2786).
-define(wxJoystickEvent_IsButton, 2787).
-define(wxJoystickEvent_IsMove, 2788).
-define(wxJoystickEvent_IsZMove, 2789).
-define(wxUpdateUIEvent_CanUpdate, 2790).
-define(wxUpdateUIEvent_Check, 2791).
-define(wxUpdateUIEvent_Enable, 2792).
-define(wxUpdateUIEvent_Show, 2793).
-define(wxUpdateUIEvent_GetChecked, 2794).
-define(wxUpdateUIEvent_GetEnabled, 2795).
-define(wxUpdateUIEvent_GetShown, 2796).
-define(wxUpdateUIEvent_GetSetChecked, 2797).
-define(wxUpdateUIEvent_GetSetEnabled, 2798).
-define(wxUpdateUIEvent_GetSetShown, 2799).
-define(wxUpdateUIEvent_GetSetText, 2800).
-define(wxUpdateUIEvent_GetText, 2801).
-define(wxUpdateUIEvent_GetMode, 2802).
-define(wxUpdateUIEvent_GetUpdateInterval, 2803).
-define(wxUpdateUIEvent_ResetUpdateTime, 2804).
-define(wxUpdateUIEvent_SetMode, 2805).
-define(wxUpdateUIEvent_SetText, 2806).
-define(wxUpdateUIEvent_SetUpdateInterval, 2807).
-define(wxMouseCaptureChangedEvent_GetCapturedWindow, 2808).
-define(wxPaletteChangedEvent_SetChangedWindow, 2809).
-define(wxPaletteChangedEvent_GetChangedWindow, 2810).
-define(wxQueryNewPaletteEvent_SetPaletteRealized, 2811).
-define(wxQueryNewPaletteEvent_GetPaletteRealized, 2812).
-define(wxNavigationKeyEvent_GetDirection, 2813).
-define(wxNavigationKeyEvent_SetDirection, 2814).
-define(wxNavigationKeyEvent_IsWindowChange, 2815).
-define(wxNavigationKeyEvent_SetWindowChange, 2816).
-define(wxNavigationKeyEvent_IsFromTab, 2817).
-define(wxNavigationKeyEvent_SetFromTab, 2818).
-define(wxNavigationKeyEvent_GetCurrentFocus, 2819).
-define(wxNavigationKeyEvent_SetCurrentFocus, 2820).
-define(wxHelpEvent_GetOrigin, 2821).
-define(wxHelpEvent_GetPosition, 2822).
-define(wxHelpEvent_SetOrigin, 2823).
-define(wxHelpEvent_SetPosition, 2824).
-define(wxContextMenuEvent_GetPosition, 2825).
-define(wxContextMenuEvent_SetPosition, 2826).
-define(wxIdleEvent_GetMode, 2827).
-define(wxIdleEvent_RequestMore, 2828).
-define(wxIdleEvent_MoreRequested, 2829).
-define(wxIdleEvent_SetMode, 2830).
-define(wxGridEvent_AltDown, 2831).
-define(wxGridEvent_ControlDown, 2832).
-define(wxGridEvent_GetCol, 2833).
-define(wxGridEvent_GetPosition, 2834).
-define(wxGridEvent_GetRow, 2835).
-define(wxGridEvent_MetaDown, 2836).
-define(wxGridEvent_Selecting, 2837).
-define(wxGridEvent_ShiftDown, 2838).
-define(wxNotifyEvent_Allow, 2839).
-define(wxNotifyEvent_IsAllowed, 2840).
-define(wxNotifyEvent_Veto, 2841).
-define(wxSashEvent_GetEdge, 2842).
-define(wxSashEvent_GetDragRect, 2843).
-define(wxSashEvent_GetDragStatus, 2844).
-define(wxListEvent_GetCacheFrom, 2845).
-define(wxListEvent_GetCacheTo, 2846).
-define(wxListEvent_GetKeyCode, 2847).
-define(wxListEvent_GetIndex, 2848).
-define(wxListEvent_GetColumn, 2849).
-define(wxListEvent_GetPoint, 2850).
-define(wxListEvent_GetLabel, 2851).
-define(wxListEvent_GetText, 2852).
-define(wxListEvent_GetImage, 2853).
-define(wxListEvent_GetData, 2854).
-define(wxListEvent_GetMask, 2855).
-define(wxListEvent_GetItem, 2856).
-define(wxListEvent_IsEditCancelled, 2857).
-define(wxDateEvent_GetDate, 2858).
-define(wxCalendarEvent_GetWeekDay, 2859).
-define(wxCalendarEvent_GetDate, 2860).
-define(wxFileDirPickerEvent_GetPath, 2861).
-define(wxColourPickerEvent_GetColour, 2862).
-define(wxFontPickerEvent_GetFont, 2863).
-define(wxStyledTextEvent_GetPosition, 2864).
-define(wxStyledTextEvent_GetKey, 2865).
-define(wxStyledTextEvent_GetModifiers, 2866).
-define(wxStyledTextEvent_GetModificationType, 2867).
-define(wxStyledTextEvent_GetText, 2868).
-define(wxStyledTextEvent_GetLength, 2869).
-define(wxStyledTextEvent_GetLinesAdded, 2870).
-define(wxStyledTextEvent_GetLine, 2871).
-define(wxStyledTextEvent_GetFoldLevelNow, 2872).
-define(wxStyledTextEvent_GetFoldLevelPrev, 2873).
-define(wxStyledTextEvent_GetMargin, 2874).
-define(wxStyledTextEvent_GetMessage, 2875).
-define(wxStyledTextEvent_GetWParam, 2876).
-define(wxStyledTextEvent_GetLParam, 2877).
-define(wxStyledTextEvent_GetListType, 2878).
-define(wxStyledTextEvent_GetX, 2879).
-define(wxStyledTextEvent_GetY, 2880).
-define(wxStyledTextEvent_GetDragText, 2881).
-define(wxStyledTextEvent_GetDragAllowMove, 2882).
-define(wxStyledTextEvent_GetDragResult, 2883).
-define(wxStyledTextEvent_GetShift, 2884).
-define(wxStyledTextEvent_GetControl, 2885).
-define(wxStyledTextEvent_GetAlt, 2886).
-define(utils_wxGetKeyState, 2887).
-define(utils_wxGetMousePosition, 2888).
-define(utils_wxGetMouseState, 2889).
-define(utils_wxSetDetectableAutoRepeat, 2890).
-define(utils_wxBell, 2891).
-define(utils_wxFindMenuItemId, 2892).
-define(utils_wxFindWindowAtPoint, 2893).
-define(utils_wxBeginBusyCursor, 2894).
-define(utils_wxEndBusyCursor, 2895).
-define(utils_wxIsBusy, 2896).
-define(utils_wxShutdown, 2897).
-define(utils_wxShell, 2898).
-define(utils_wxLaunchDefaultBrowser, 2899).
-define(utils_wxGetEmailAddress, 2900).
-define(utils_wxGetUserId, 2901).
-define(utils_wxGetHomeDir, 2902).
-define(utils_wxNewId, 2903).
-define(utils_wxRegisterId, 2904).
-define(utils_wxGetCurrentId, 2905).
-define(utils_wxGetOsDescription, 2906).
-define(utils_wxIsPlatformLittleEndian, 2907).
-define(utils_wxIsPlatform64Bit, 2908).
-define(gdicmn_wxDisplaySize, 2909).
-define(gdicmn_wxSetCursor, 2910).
-define(wxPrintout_new, 2911).
-define(wxPrintout_destruct, 2912).
-define(wxPrintout_GetDC, 2913).
-define(wxPrintout_GetPageSizeMM, 2914).
-define(wxPrintout_GetPageSizePixels, 2915).
-define(wxPrintout_GetPaperRectPixels, 2916).
-define(wxPrintout_GetPPIPrinter, 2917).
-define(wxPrintout_GetPPIScreen, 2918).
-define(wxPrintout_GetTitle, 2919).
-define(wxPrintout_IsPreview, 2920).
-define(wxPrintout_FitThisSizeToPaper, 2921).
-define(wxPrintout_FitThisSizeToPage, 2922).
-define(wxPrintout_FitThisSizeToPageMargins, 2923).
-define(wxPrintout_MapScreenSizeToPaper, 2924).
-define(wxPrintout_MapScreenSizeToPage, 2925).
-define(wxPrintout_MapScreenSizeToPageMargins, 2926).
-define(wxPrintout_MapScreenSizeToDevice, 2927).
-define(wxPrintout_GetLogicalPaperRect, 2928).
-define(wxPrintout_GetLogicalPageRect, 2929).
-define(wxPrintout_GetLogicalPageMarginsRect, 2930).
-define(wxPrintout_SetLogicalOrigin, 2931).
-define(wxPrintout_OffsetLogicalOrigin, 2932).
-define(wxStyledTextCtrl_new_2, 2933).
-define(wxStyledTextCtrl_new_0, 2934).
-define(wxStyledTextCtrl_destruct, 2935).
-define(wxStyledTextCtrl_Create, 2936).
-define(wxStyledTextCtrl_AddText, 2937).
-define(wxStyledTextCtrl_InsertText, 2938).
-define(wxStyledTextCtrl_ClearAll, 2939).
-define(wxStyledTextCtrl_ClearDocumentStyle, 2940).
-define(wxStyledTextCtrl_GetLength, 2941).
-define(wxStyledTextCtrl_GetCharAt, 2942).
-define(wxStyledTextCtrl_GetCurrentPos, 2943).
-define(wxStyledTextCtrl_GetAnchor, 2944).
-define(wxStyledTextCtrl_GetStyleAt, 2945).
-define(wxStyledTextCtrl_Redo, 2946).
-define(wxStyledTextCtrl_SetUndoCollection, 2947).
-define(wxStyledTextCtrl_SelectAll, 2948).
-define(wxStyledTextCtrl_SetSavePoint, 2949).
-define(wxStyledTextCtrl_CanRedo, 2950).
-define(wxStyledTextCtrl_MarkerLineFromHandle, 2951).
-define(wxStyledTextCtrl_MarkerDeleteHandle, 2952).
-define(wxStyledTextCtrl_GetUndoCollection, 2953).
-define(wxStyledTextCtrl_GetViewWhiteSpace, 2954).
-define(wxStyledTextCtrl_SetViewWhiteSpace, 2955).
-define(wxStyledTextCtrl_PositionFromPoint, 2956).
-define(wxStyledTextCtrl_PositionFromPointClose, 2957).
-define(wxStyledTextCtrl_GotoLine, 2958).
-define(wxStyledTextCtrl_GotoPos, 2959).
-define(wxStyledTextCtrl_SetAnchor, 2960).
-define(wxStyledTextCtrl_GetCurLine, 2961).
-define(wxStyledTextCtrl_GetEndStyled, 2962).
-define(wxStyledTextCtrl_ConvertEOLs, 2963).
-define(wxStyledTextCtrl_GetEOLMode, 2964).
-define(wxStyledTextCtrl_SetEOLMode, 2965).
-define(wxStyledTextCtrl_StartStyling, 2966).
-define(wxStyledTextCtrl_SetStyling, 2967).
-define(wxStyledTextCtrl_GetBufferedDraw, 2968).
-define(wxStyledTextCtrl_SetBufferedDraw, 2969).
-define(wxStyledTextCtrl_SetTabWidth, 2970).
-define(wxStyledTextCtrl_GetTabWidth, 2971).
-define(wxStyledTextCtrl_SetCodePage, 2972).
-define(wxStyledTextCtrl_MarkerDefine, 2973).
-define(wxStyledTextCtrl_MarkerSetForeground, 2974).
-define(wxStyledTextCtrl_MarkerSetBackground, 2975).
-define(wxStyledTextCtrl_MarkerAdd, 2976).
-define(wxStyledTextCtrl_MarkerDelete, 2977).
-define(wxStyledTextCtrl_MarkerDeleteAll, 2978).
-define(wxStyledTextCtrl_MarkerGet, 2979).
-define(wxStyledTextCtrl_MarkerNext, 2980).
-define(wxStyledTextCtrl_MarkerPrevious, 2981).
-define(wxStyledTextCtrl_MarkerDefineBitmap, 2982).
-define(wxStyledTextCtrl_MarkerAddSet, 2983).
-define(wxStyledTextCtrl_MarkerSetAlpha, 2984).
-define(wxStyledTextCtrl_SetMarginType, 2985).
-define(wxStyledTextCtrl_GetMarginType, 2986).
-define(wxStyledTextCtrl_SetMarginWidth, 2987).
-define(wxStyledTextCtrl_GetMarginWidth, 2988).
-define(wxStyledTextCtrl_SetMarginMask, 2989).
-define(wxStyledTextCtrl_GetMarginMask, 2990).
-define(wxStyledTextCtrl_SetMarginSensitive, 2991).
-define(wxStyledTextCtrl_GetMarginSensitive, 2992).
-define(wxStyledTextCtrl_StyleClearAll, 2993).
-define(wxStyledTextCtrl_StyleSetForeground, 2994).
-define(wxStyledTextCtrl_StyleSetBackground, 2995).
-define(wxStyledTextCtrl_StyleSetBold, 2996).
-define(wxStyledTextCtrl_StyleSetItalic, 2997).
-define(wxStyledTextCtrl_StyleSetSize, 2998).
-define(wxStyledTextCtrl_StyleSetFaceName, 2999).
-define(wxStyledTextCtrl_StyleSetEOLFilled, 3000).
-define(wxStyledTextCtrl_StyleResetDefault, 3001).
-define(wxStyledTextCtrl_StyleSetUnderline, 3002).
-define(wxStyledTextCtrl_StyleSetCase, 3003).
-define(wxStyledTextCtrl_StyleSetHotSpot, 3004).
-define(wxStyledTextCtrl_SetSelForeground, 3005).
-define(wxStyledTextCtrl_SetSelBackground, 3006).
-define(wxStyledTextCtrl_GetSelAlpha, 3007).
-define(wxStyledTextCtrl_SetSelAlpha, 3008).
-define(wxStyledTextCtrl_SetCaretForeground, 3009).
-define(wxStyledTextCtrl_CmdKeyAssign, 3010).
-define(wxStyledTextCtrl_CmdKeyClear, 3011).
-define(wxStyledTextCtrl_CmdKeyClearAll, 3012).
-define(wxStyledTextCtrl_SetStyleBytes, 3013).
-define(wxStyledTextCtrl_StyleSetVisible, 3014).
-define(wxStyledTextCtrl_GetCaretPeriod, 3015).
-define(wxStyledTextCtrl_SetCaretPeriod, 3016).
-define(wxStyledTextCtrl_SetWordChars, 3017).
-define(wxStyledTextCtrl_BeginUndoAction, 3018).
-define(wxStyledTextCtrl_EndUndoAction, 3019).
-define(wxStyledTextCtrl_IndicatorSetStyle, 3020).
-define(wxStyledTextCtrl_IndicatorGetStyle, 3021).
-define(wxStyledTextCtrl_IndicatorSetForeground, 3022).
-define(wxStyledTextCtrl_IndicatorGetForeground, 3023).
-define(wxStyledTextCtrl_SetWhitespaceForeground, 3024).
-define(wxStyledTextCtrl_SetWhitespaceBackground, 3025).
-define(wxStyledTextCtrl_GetStyleBits, 3026).
-define(wxStyledTextCtrl_SetLineState, 3027).
-define(wxStyledTextCtrl_GetLineState, 3028).
-define(wxStyledTextCtrl_GetMaxLineState, 3029).
-define(wxStyledTextCtrl_GetCaretLineVisible, 3030).
-define(wxStyledTextCtrl_SetCaretLineVisible, 3031).
-define(wxStyledTextCtrl_GetCaretLineBackground, 3032).
-define(wxStyledTextCtrl_SetCaretLineBackground, 3033).
-define(wxStyledTextCtrl_AutoCompShow, 3034).
-define(wxStyledTextCtrl_AutoCompCancel, 3035).
-define(wxStyledTextCtrl_AutoCompActive, 3036).
-define(wxStyledTextCtrl_AutoCompPosStart, 3037).
-define(wxStyledTextCtrl_AutoCompComplete, 3038).
-define(wxStyledTextCtrl_AutoCompStops, 3039).
-define(wxStyledTextCtrl_AutoCompSetSeparator, 3040).
-define(wxStyledTextCtrl_AutoCompGetSeparator, 3041).
-define(wxStyledTextCtrl_AutoCompSelect, 3042).
-define(wxStyledTextCtrl_AutoCompSetCancelAtStart, 3043).
-define(wxStyledTextCtrl_AutoCompGetCancelAtStart, 3044).
-define(wxStyledTextCtrl_AutoCompSetFillUps, 3045).
-define(wxStyledTextCtrl_AutoCompSetChooseSingle, 3046).
-define(wxStyledTextCtrl_AutoCompGetChooseSingle, 3047).
-define(wxStyledTextCtrl_AutoCompSetIgnoreCase, 3048).
-define(wxStyledTextCtrl_AutoCompGetIgnoreCase, 3049).
-define(wxStyledTextCtrl_UserListShow, 3050).
-define(wxStyledTextCtrl_AutoCompSetAutoHide, 3051).
-define(wxStyledTextCtrl_AutoCompGetAutoHide, 3052).
-define(wxStyledTextCtrl_AutoCompSetDropRestOfWord, 3053).
-define(wxStyledTextCtrl_AutoCompGetDropRestOfWord, 3054).
-define(wxStyledTextCtrl_RegisterImage, 3055).
-define(wxStyledTextCtrl_ClearRegisteredImages, 3056).
-define(wxStyledTextCtrl_AutoCompGetTypeSeparator, 3057).
-define(wxStyledTextCtrl_AutoCompSetTypeSeparator, 3058).
-define(wxStyledTextCtrl_AutoCompSetMaxWidth, 3059).
-define(wxStyledTextCtrl_AutoCompGetMaxWidth, 3060).
-define(wxStyledTextCtrl_AutoCompSetMaxHeight, 3061).
-define(wxStyledTextCtrl_AutoCompGetMaxHeight, 3062).
-define(wxStyledTextCtrl_SetIndent, 3063).
-define(wxStyledTextCtrl_GetIndent, 3064).
-define(wxStyledTextCtrl_SetUseTabs, 3065).
-define(wxStyledTextCtrl_GetUseTabs, 3066).
-define(wxStyledTextCtrl_SetLineIndentation, 3067).
-define(wxStyledTextCtrl_GetLineIndentation, 3068).
-define(wxStyledTextCtrl_GetLineIndentPosition, 3069).
-define(wxStyledTextCtrl_GetColumn, 3070).
-define(wxStyledTextCtrl_SetUseHorizontalScrollBar, 3071).
-define(wxStyledTextCtrl_GetUseHorizontalScrollBar, 3072).
-define(wxStyledTextCtrl_SetIndentationGuides, 3073).
-define(wxStyledTextCtrl_GetIndentationGuides, 3074).
-define(wxStyledTextCtrl_SetHighlightGuide, 3075).
-define(wxStyledTextCtrl_GetHighlightGuide, 3076).
-define(wxStyledTextCtrl_GetLineEndPosition, 3077).
-define(wxStyledTextCtrl_GetCodePage, 3078).
-define(wxStyledTextCtrl_GetCaretForeground, 3079).
-define(wxStyledTextCtrl_GetReadOnly, 3080).
-define(wxStyledTextCtrl_SetCurrentPos, 3081).
-define(wxStyledTextCtrl_SetSelectionStart, 3082).
-define(wxStyledTextCtrl_GetSelectionStart, 3083).
-define(wxStyledTextCtrl_SetSelectionEnd, 3084).
-define(wxStyledTextCtrl_GetSelectionEnd, 3085).
-define(wxStyledTextCtrl_SetPrintMagnification, 3086).
-define(wxStyledTextCtrl_GetPrintMagnification, 3087).
-define(wxStyledTextCtrl_SetPrintColourMode, 3088).
-define(wxStyledTextCtrl_GetPrintColourMode, 3089).
-define(wxStyledTextCtrl_FindText, 3090).
-define(wxStyledTextCtrl_FormatRange, 3091).
-define(wxStyledTextCtrl_GetFirstVisibleLine, 3092).
-define(wxStyledTextCtrl_GetLine, 3093).
-define(wxStyledTextCtrl_GetLineCount, 3094).
-define(wxStyledTextCtrl_SetMarginLeft, 3095).
-define(wxStyledTextCtrl_GetMarginLeft, 3096).
-define(wxStyledTextCtrl_SetMarginRight, 3097).
-define(wxStyledTextCtrl_GetMarginRight, 3098).
-define(wxStyledTextCtrl_GetModify, 3099).
-define(wxStyledTextCtrl_SetSelection, 3100).
-define(wxStyledTextCtrl_GetSelectedText, 3101).
-define(wxStyledTextCtrl_GetTextRange, 3102).
-define(wxStyledTextCtrl_HideSelection, 3103).
-define(wxStyledTextCtrl_LineFromPosition, 3104).
-define(wxStyledTextCtrl_PositionFromLine, 3105).
-define(wxStyledTextCtrl_LineScroll, 3106).
-define(wxStyledTextCtrl_EnsureCaretVisible, 3107).
-define(wxStyledTextCtrl_ReplaceSelection, 3108).
-define(wxStyledTextCtrl_SetReadOnly, 3109).
-define(wxStyledTextCtrl_CanPaste, 3110).
-define(wxStyledTextCtrl_CanUndo, 3111).
-define(wxStyledTextCtrl_EmptyUndoBuffer, 3112).
-define(wxStyledTextCtrl_Undo, 3113).
-define(wxStyledTextCtrl_Cut, 3114).
-define(wxStyledTextCtrl_Copy, 3115).
-define(wxStyledTextCtrl_Paste, 3116).
-define(wxStyledTextCtrl_Clear, 3117).
-define(wxStyledTextCtrl_SetText, 3118).
-define(wxStyledTextCtrl_GetText, 3119).
-define(wxStyledTextCtrl_GetTextLength, 3120).
-define(wxStyledTextCtrl_GetOvertype, 3121).
-define(wxStyledTextCtrl_SetCaretWidth, 3122).
-define(wxStyledTextCtrl_GetCaretWidth, 3123).
-define(wxStyledTextCtrl_SetTargetStart, 3124).
-define(wxStyledTextCtrl_GetTargetStart, 3125).
-define(wxStyledTextCtrl_SetTargetEnd, 3126).
-define(wxStyledTextCtrl_GetTargetEnd, 3127).
-define(wxStyledTextCtrl_ReplaceTarget, 3128).
-define(wxStyledTextCtrl_SearchInTarget, 3129).
-define(wxStyledTextCtrl_SetSearchFlags, 3130).
-define(wxStyledTextCtrl_GetSearchFlags, 3131).
-define(wxStyledTextCtrl_CallTipShow, 3132).
-define(wxStyledTextCtrl_CallTipCancel, 3133).
-define(wxStyledTextCtrl_CallTipActive, 3134).
-define(wxStyledTextCtrl_CallTipPosAtStart, 3135).
-define(wxStyledTextCtrl_CallTipSetHighlight, 3136).
-define(wxStyledTextCtrl_CallTipSetBackground, 3137).
-define(wxStyledTextCtrl_CallTipSetForeground, 3138).
-define(wxStyledTextCtrl_CallTipSetForegroundHighlight, 3139).
-define(wxStyledTextCtrl_CallTipUseStyle, 3140).
-define(wxStyledTextCtrl_VisibleFromDocLine, 3141).
-define(wxStyledTextCtrl_DocLineFromVisible, 3142).
-define(wxStyledTextCtrl_WrapCount, 3143).
-define(wxStyledTextCtrl_SetFoldLevel, 3144).
-define(wxStyledTextCtrl_GetFoldLevel, 3145).
-define(wxStyledTextCtrl_GetLastChild, 3146).
-define(wxStyledTextCtrl_GetFoldParent, 3147).
-define(wxStyledTextCtrl_ShowLines, 3148).
-define(wxStyledTextCtrl_HideLines, 3149).
-define(wxStyledTextCtrl_GetLineVisible, 3150).
-define(wxStyledTextCtrl_SetFoldExpanded, 3151).
-define(wxStyledTextCtrl_GetFoldExpanded, 3152).
-define(wxStyledTextCtrl_ToggleFold, 3153).
-define(wxStyledTextCtrl_EnsureVisible, 3154).
-define(wxStyledTextCtrl_SetFoldFlags, 3155).
-define(wxStyledTextCtrl_EnsureVisibleEnforcePolicy, 3156).
-define(wxStyledTextCtrl_SetTabIndents, 3157).
-define(wxStyledTextCtrl_GetTabIndents, 3158).
-define(wxStyledTextCtrl_SetBackSpaceUnIndents, 3159).
-define(wxStyledTextCtrl_GetBackSpaceUnIndents, 3160).
-define(wxStyledTextCtrl_SetMouseDwellTime, 3161).
-define(wxStyledTextCtrl_GetMouseDwellTime, 3162).
-define(wxStyledTextCtrl_WordStartPosition, 3163).
-define(wxStyledTextCtrl_WordEndPosition, 3164).
-define(wxStyledTextCtrl_SetWrapMode, 3165).
-define(wxStyledTextCtrl_GetWrapMode, 3166).
-define(wxStyledTextCtrl_SetWrapVisualFlags, 3167).
-define(wxStyledTextCtrl_GetWrapVisualFlags, 3168).
-define(wxStyledTextCtrl_SetWrapVisualFlagsLocation, 3169).
-define(wxStyledTextCtrl_GetWrapVisualFlagsLocation, 3170).
-define(wxStyledTextCtrl_SetWrapStartIndent, 3171).
-define(wxStyledTextCtrl_GetWrapStartIndent, 3172).
-define(wxStyledTextCtrl_SetLayoutCache, 3173).
-define(wxStyledTextCtrl_GetLayoutCache, 3174).
-define(wxStyledTextCtrl_SetScrollWidth, 3175).
-define(wxStyledTextCtrl_GetScrollWidth, 3176).
-define(wxStyledTextCtrl_TextWidth, 3177).
-define(wxStyledTextCtrl_GetEndAtLastLine, 3178).
-define(wxStyledTextCtrl_TextHeight, 3179).
-define(wxStyledTextCtrl_SetUseVerticalScrollBar, 3180).
-define(wxStyledTextCtrl_GetUseVerticalScrollBar, 3181).
-define(wxStyledTextCtrl_AppendText, 3182).
-define(wxStyledTextCtrl_GetTwoPhaseDraw, 3183).
-define(wxStyledTextCtrl_SetTwoPhaseDraw, 3184).
-define(wxStyledTextCtrl_TargetFromSelection, 3185).
-define(wxStyledTextCtrl_LinesJoin, 3186).
-define(wxStyledTextCtrl_LinesSplit, 3187).
-define(wxStyledTextCtrl_SetFoldMarginColour, 3188).
-define(wxStyledTextCtrl_SetFoldMarginHiColour, 3189).
-define(wxStyledTextCtrl_LineDown, 3190).
-define(wxStyledTextCtrl_LineDownExtend, 3191).
-define(wxStyledTextCtrl_LineUp, 3192).
-define(wxStyledTextCtrl_LineUpExtend, 3193).
-define(wxStyledTextCtrl_CharLeft, 3194).
-define(wxStyledTextCtrl_CharLeftExtend, 3195).
-define(wxStyledTextCtrl_CharRight, 3196).
-define(wxStyledTextCtrl_CharRightExtend, 3197).
-define(wxStyledTextCtrl_WordLeft, 3198).
-define(wxStyledTextCtrl_WordLeftExtend, 3199).
-define(wxStyledTextCtrl_WordRight, 3200).
-define(wxStyledTextCtrl_WordRightExtend, 3201).
-define(wxStyledTextCtrl_Home, 3202).
-define(wxStyledTextCtrl_HomeExtend, 3203).
-define(wxStyledTextCtrl_LineEnd, 3204).
-define(wxStyledTextCtrl_LineEndExtend, 3205).
-define(wxStyledTextCtrl_DocumentStart, 3206).
-define(wxStyledTextCtrl_DocumentStartExtend, 3207).
-define(wxStyledTextCtrl_DocumentEnd, 3208).
-define(wxStyledTextCtrl_DocumentEndExtend, 3209).
-define(wxStyledTextCtrl_PageUp, 3210).
-define(wxStyledTextCtrl_PageUpExtend, 3211).
-define(wxStyledTextCtrl_PageDown, 3212).
-define(wxStyledTextCtrl_PageDownExtend, 3213).
-define(wxStyledTextCtrl_EditToggleOvertype, 3214).
-define(wxStyledTextCtrl_Cancel, 3215).
-define(wxStyledTextCtrl_DeleteBack, 3216).
-define(wxStyledTextCtrl_Tab, 3217).
-define(wxStyledTextCtrl_BackTab, 3218).
-define(wxStyledTextCtrl_NewLine, 3219).
-define(wxStyledTextCtrl_FormFeed, 3220).
-define(wxStyledTextCtrl_VCHome, 3221).
-define(wxStyledTextCtrl_VCHomeExtend, 3222).
-define(wxStyledTextCtrl_ZoomIn, 3223).
-define(wxStyledTextCtrl_ZoomOut, 3224).
-define(wxStyledTextCtrl_DelWordLeft, 3225).
-define(wxStyledTextCtrl_DelWordRight, 3226).
-define(wxStyledTextCtrl_LineCut, 3227).
-define(wxStyledTextCtrl_LineDelete, 3228).
-define(wxStyledTextCtrl_LineTranspose, 3229).
-define(wxStyledTextCtrl_LineDuplicate, 3230).
-define(wxStyledTextCtrl_LowerCase, 3231).
-define(wxStyledTextCtrl_UpperCase, 3232).
-define(wxStyledTextCtrl_LineScrollDown, 3233).
-define(wxStyledTextCtrl_LineScrollUp, 3234).
-define(wxStyledTextCtrl_DeleteBackNotLine, 3235).
-define(wxStyledTextCtrl_HomeDisplay, 3236).
-define(wxStyledTextCtrl_HomeDisplayExtend, 3237).
-define(wxStyledTextCtrl_LineEndDisplay, 3238).
-define(wxStyledTextCtrl_LineEndDisplayExtend, 3239).
-define(wxStyledTextCtrl_HomeWrapExtend, 3240).
-define(wxStyledTextCtrl_LineEndWrap, 3241).
-define(wxStyledTextCtrl_LineEndWrapExtend, 3242).
-define(wxStyledTextCtrl_VCHomeWrap, 3243).
-define(wxStyledTextCtrl_VCHomeWrapExtend, 3244).
-define(wxStyledTextCtrl_LineCopy, 3245).
-define(wxStyledTextCtrl_MoveCaretInsideView, 3246).
-define(wxStyledTextCtrl_LineLength, 3247).
-define(wxStyledTextCtrl_BraceHighlight, 3248).
-define(wxStyledTextCtrl_BraceBadLight, 3249).
-define(wxStyledTextCtrl_BraceMatch, 3250).
-define(wxStyledTextCtrl_GetViewEOL, 3251).
-define(wxStyledTextCtrl_SetViewEOL, 3252).
-define(wxStyledTextCtrl_SetModEventMask, 3253).
-define(wxStyledTextCtrl_GetEdgeColumn, 3254).
-define(wxStyledTextCtrl_SetEdgeColumn, 3255).
-define(wxStyledTextCtrl_SetEdgeMode, 3256).
-define(wxStyledTextCtrl_GetEdgeMode, 3257).
-define(wxStyledTextCtrl_GetEdgeColour, 3258).
-define(wxStyledTextCtrl_SetEdgeColour, 3259).
-define(wxStyledTextCtrl_SearchAnchor, 3260).
-define(wxStyledTextCtrl_SearchNext, 3261).
-define(wxStyledTextCtrl_SearchPrev, 3262).
-define(wxStyledTextCtrl_LinesOnScreen, 3263).
-define(wxStyledTextCtrl_UsePopUp, 3264).
-define(wxStyledTextCtrl_SelectionIsRectangle, 3265).
-define(wxStyledTextCtrl_SetZoom, 3266).
-define(wxStyledTextCtrl_GetZoom, 3267).
-define(wxStyledTextCtrl_GetModEventMask, 3268).
-define(wxStyledTextCtrl_SetSTCFocus, 3269).
-define(wxStyledTextCtrl_GetSTCFocus, 3270).
-define(wxStyledTextCtrl_SetStatus, 3271).
-define(wxStyledTextCtrl_GetStatus, 3272).
-define(wxStyledTextCtrl_SetMouseDownCaptures, 3273).
-define(wxStyledTextCtrl_GetMouseDownCaptures, 3274).
-define(wxStyledTextCtrl_SetSTCCursor, 3275).
-define(wxStyledTextCtrl_GetSTCCursor, 3276).
-define(wxStyledTextCtrl_SetControlCharSymbol, 3277).
-define(wxStyledTextCtrl_GetControlCharSymbol, 3278).
-define(wxStyledTextCtrl_WordPartLeft, 3279).
-define(wxStyledTextCtrl_WordPartLeftExtend, 3280).
-define(wxStyledTextCtrl_WordPartRight, 3281).
-define(wxStyledTextCtrl_WordPartRightExtend, 3282).
-define(wxStyledTextCtrl_SetVisiblePolicy, 3283).
-define(wxStyledTextCtrl_DelLineLeft, 3284).
-define(wxStyledTextCtrl_DelLineRight, 3285).
-define(wxStyledTextCtrl_GetXOffset, 3286).
-define(wxStyledTextCtrl_ChooseCaretX, 3287).
-define(wxStyledTextCtrl_SetXCaretPolicy, 3288).
-define(wxStyledTextCtrl_SetYCaretPolicy, 3289).
-define(wxStyledTextCtrl_GetPrintWrapMode, 3290).
-define(wxStyledTextCtrl_SetHotspotActiveForeground, 3291).
-define(wxStyledTextCtrl_SetHotspotActiveBackground, 3292).
-define(wxStyledTextCtrl_SetHotspotActiveUnderline, 3293).
-define(wxStyledTextCtrl_SetHotspotSingleLine, 3294).
-define(wxStyledTextCtrl_ParaDownExtend, 3295).
-define(wxStyledTextCtrl_ParaUp, 3296).
-define(wxStyledTextCtrl_ParaUpExtend, 3297).
-define(wxStyledTextCtrl_PositionBefore, 3298).
-define(wxStyledTextCtrl_PositionAfter, 3299).
-define(wxStyledTextCtrl_CopyRange, 3300).
-define(wxStyledTextCtrl_CopyText, 3301).
-define(wxStyledTextCtrl_SetSelectionMode, 3302).
-define(wxStyledTextCtrl_GetSelectionMode, 3303).
-define(wxStyledTextCtrl_LineDownRectExtend, 3304).
-define(wxStyledTextCtrl_LineUpRectExtend, 3305).
-define(wxStyledTextCtrl_CharLeftRectExtend, 3306).
-define(wxStyledTextCtrl_CharRightRectExtend, 3307).
-define(wxStyledTextCtrl_HomeRectExtend, 3308).
-define(wxStyledTextCtrl_VCHomeRectExtend, 3309).
-define(wxStyledTextCtrl_LineEndRectExtend, 3310).
-define(wxStyledTextCtrl_PageUpRectExtend, 3311).
-define(wxStyledTextCtrl_PageDownRectExtend, 3312).
-define(wxStyledTextCtrl_StutteredPageUp, 3313).
-define(wxStyledTextCtrl_StutteredPageUpExtend, 3314).
-define(wxStyledTextCtrl_StutteredPageDown, 3315).
-define(wxStyledTextCtrl_StutteredPageDownExtend, 3316).
-define(wxStyledTextCtrl_WordLeftEnd, 3317).
-define(wxStyledTextCtrl_WordLeftEndExtend, 3318).
-define(wxStyledTextCtrl_WordRightEnd, 3319).
-define(wxStyledTextCtrl_WordRightEndExtend, 3320).
-define(wxStyledTextCtrl_SetWhitespaceChars, 3321).
-define(wxStyledTextCtrl_SetCharsDefault, 3322).
-define(wxStyledTextCtrl_AutoCompGetCurrent, 3323).
-define(wxStyledTextCtrl_Allocate, 3324).
-define(wxStyledTextCtrl_FindColumn, 3325).
-define(wxStyledTextCtrl_GetCaretSticky, 3326).
-define(wxStyledTextCtrl_SetCaretSticky, 3327).
-define(wxStyledTextCtrl_ToggleCaretSticky, 3328).
-define(wxStyledTextCtrl_SetPasteConvertEndings, 3329).
-define(wxStyledTextCtrl_GetPasteConvertEndings, 3330).
-define(wxStyledTextCtrl_SelectionDuplicate, 3331).
-define(wxStyledTextCtrl_SetCaretLineBackAlpha, 3332).
-define(wxStyledTextCtrl_GetCaretLineBackAlpha, 3333).
-define(wxStyledTextCtrl_StartRecord, 3334).
-define(wxStyledTextCtrl_StopRecord, 3335).
-define(wxStyledTextCtrl_SetLexer, 3336).
-define(wxStyledTextCtrl_GetLexer, 3337).
-define(wxStyledTextCtrl_Colourise, 3338).
-define(wxStyledTextCtrl_SetProperty, 3339).
-define(wxStyledTextCtrl_SetKeyWords, 3340).
-define(wxStyledTextCtrl_SetLexerLanguage, 3341).
-define(wxStyledTextCtrl_GetProperty, 3342).
-define(wxStyledTextCtrl_GetStyleBitsNeeded, 3343).
-define(wxStyledTextCtrl_GetCurrentLine, 3344).
-define(wxStyledTextCtrl_StyleSetSpec, 3345).
-define(wxStyledTextCtrl_StyleSetFont, 3346).
-define(wxStyledTextCtrl_StyleSetFontAttr, 3347).
-define(wxStyledTextCtrl_StyleSetCharacterSet, 3348).
-define(wxStyledTextCtrl_StyleSetFontEncoding, 3349).
-define(wxStyledTextCtrl_CmdKeyExecute, 3350).
-define(wxStyledTextCtrl_SetMargins, 3351).
-define(wxStyledTextCtrl_GetSelection, 3352).
-define(wxStyledTextCtrl_PointFromPosition, 3353).
-define(wxStyledTextCtrl_ScrollToLine, 3354).
-define(wxStyledTextCtrl_ScrollToColumn, 3355).
-define(wxStyledTextCtrl_SetVScrollBar, 3356).
-define(wxStyledTextCtrl_SetHScrollBar, 3357).
-define(wxStyledTextCtrl_GetLastKeydownProcessed, 3358).
-define(wxStyledTextCtrl_SetLastKeydownProcessed, 3359).
-define(wxStyledTextCtrl_SaveFile, 3360).
-define(wxStyledTextCtrl_LoadFile, 3361).
-define(wxStyledTextCtrl_DoDragOver, 3362).
-define(wxStyledTextCtrl_DoDropText, 3363).
-define(wxStyledTextCtrl_GetUseAntiAliasing, 3364).
-define(wxStyledTextCtrl_AddTextRaw, 3365).
-define(wxStyledTextCtrl_InsertTextRaw, 3366).
-define(wxStyledTextCtrl_GetCurLineRaw, 3367).
-define(wxStyledTextCtrl_GetLineRaw, 3368).
-define(wxStyledTextCtrl_GetSelectedTextRaw, 3369).
-define(wxStyledTextCtrl_GetTextRangeRaw, 3370).
-define(wxStyledTextCtrl_SetTextRaw, 3371).
-define(wxStyledTextCtrl_GetTextRaw, 3372).
-define(wxStyledTextCtrl_AppendTextRaw, 3373).
-define(wxArtProvider_GetBitmap, 3374).
-define(wxArtProvider_GetIcon, 3375).
-define(wxTreeEvent_GetKeyCode, 3376).
-define(wxTreeEvent_GetItem, 3377).
-define(wxTreeEvent_GetKeyEvent, 3378).
-define(wxTreeEvent_GetLabel, 3379).
-define(wxTreeEvent_GetOldItem, 3380).
-define(wxTreeEvent_GetPoint, 3381).
-define(wxTreeEvent_IsEditCancelled, 3382).
-define(wxTreeEvent_SetToolTip, 3383).
-define(wxBookCtrlEvent_GetOldSelection, 3384).
-define(wxBookCtrlEvent_GetSelection, 3385).
-define(wxBookCtrlEvent_SetOldSelection, 3386).
-define(wxBookCtrlEvent_SetSelection, 3387).
-define(wxFileDataObject_new, 3388).
-define(wxFileDataObject_AddFile, 3389).
-define(wxFileDataObject_GetFilenames, 3390).
-define(wxFileDataObject_destroy, 3391).
-define(wxTextDataObject_new, 3392).
-define(wxTextDataObject_GetTextLength, 3393).
-define(wxTextDataObject_GetText, 3394).
-define(wxTextDataObject_SetText, 3395).
-define(wxTextDataObject_destroy, 3396).
-define(wxBitmapDataObject_new_1_1, 3397).
-define(wxBitmapDataObject_new_1_0, 3398).
-define(wxBitmapDataObject_GetBitmap, 3399).
-define(wxBitmapDataObject_SetBitmap, 3400).
-define(wxBitmapDataObject_destroy, 3401).
-define(wxClipboard_new, 3402).
-define(wxClipboard_destruct, 3403).
-define(wxClipboard_AddData, 3404).
-define(wxClipboard_Clear, 3405).
-define(wxClipboard_Close, 3406).
-define(wxClipboard_Flush, 3407).
-define(wxClipboard_GetData, 3408).
-define(wxClipboard_IsOpened, 3409).
-define(wxClipboard_Open, 3410).
-define(wxClipboard_SetData, 3411).
-define(wxClipboard_UsePrimarySelection, 3412).
-define(wxClipboard_IsSupported, 3413).
-define(wxClipboard_Get, 3414).
-define(wxSpinEvent_GetPosition, 3415).
-define(wxSpinEvent_SetPosition, 3416).
-define(wxSplitterWindow_new_0, 3417).
-define(wxSplitterWindow_new_2, 3418).
-define(wxSplitterWindow_destruct, 3419).
-define(wxSplitterWindow_Create, 3420).
-define(wxSplitterWindow_GetMinimumPaneSize, 3421).
-define(wxSplitterWindow_GetSashGravity, 3422).
-define(wxSplitterWindow_GetSashPosition, 3423).
-define(wxSplitterWindow_GetSplitMode, 3424).
-define(wxSplitterWindow_GetWindow1, 3425).
-define(wxSplitterWindow_GetWindow2, 3426).
-define(wxSplitterWindow_Initialize, 3427).
-define(wxSplitterWindow_IsSplit, 3428).
-define(wxSplitterWindow_ReplaceWindow, 3429).
-define(wxSplitterWindow_SetSashGravity, 3430).
-define(wxSplitterWindow_SetSashPosition, 3431).
-define(wxSplitterWindow_SetMinimumPaneSize, 3432).
-define(wxSplitterWindow_SetSplitMode, 3433).
-define(wxSplitterWindow_SplitHorizontally, 3434).
-define(wxSplitterWindow_SplitVertically, 3435).
-define(wxSplitterWindow_Unsplit, 3436).
-define(wxSplitterWindow_UpdateSize, 3437).
-define(wxSplitterEvent_GetSashPosition, 3438).
-define(wxSplitterEvent_GetX, 3439).
-define(wxSplitterEvent_GetY, 3440).
-define(wxSplitterEvent_GetWindowBeingRemoved, 3441).
-define(wxSplitterEvent_SetSashPosition, 3442).
-define(wxHtmlWindow_new_0, 3443).
-define(wxHtmlWindow_new_2, 3444).
-define(wxHtmlWindow_AppendToPage, 3445).
-define(wxHtmlWindow_GetOpenedAnchor, 3446).
-define(wxHtmlWindow_GetOpenedPage, 3447).
-define(wxHtmlWindow_GetOpenedPageTitle, 3448).
-define(wxHtmlWindow_GetRelatedFrame, 3449).
-define(wxHtmlWindow_HistoryBack, 3450).
-define(wxHtmlWindow_HistoryCanBack, 3451).
-define(wxHtmlWindow_HistoryCanForward, 3452).
-define(wxHtmlWindow_HistoryClear, 3453).
-define(wxHtmlWindow_HistoryForward, 3454).
-define(wxHtmlWindow_LoadFile, 3455).
-define(wxHtmlWindow_LoadPage, 3456).
-define(wxHtmlWindow_SelectAll, 3457).
-define(wxHtmlWindow_SelectionToText, 3458).
-define(wxHtmlWindow_SelectLine, 3459).
-define(wxHtmlWindow_SelectWord, 3460).
-define(wxHtmlWindow_SetBorders, 3461).
-define(wxHtmlWindow_SetFonts, 3462).
-define(wxHtmlWindow_SetPage, 3463).
-define(wxHtmlWindow_SetRelatedFrame, 3464).
-define(wxHtmlWindow_SetRelatedStatusBar_1, 3465).
-define(wxHtmlWindow_SetRelatedStatusBar_2, 3466).
-define(wxHtmlWindow_ToText, 3467).
-define(wxHtmlWindow_destroy, 3468).
-define(wxHtmlLinkEvent_GetLinkInfo, 3469).
-define(wxSystemSettings_GetColour, 3470).
-define(wxSystemSettings_GetFont, 3471).
-define(wxSystemSettings_GetMetric, 3472).
-define(wxSystemSettings_GetScreenType, 3473).
-define(wxSystemOptions_GetOption, 3474).
-define(wxSystemOptions_GetOptionInt, 3475).
-define(wxSystemOptions_HasOption, 3476).
-define(wxSystemOptions_IsFalse, 3477).
-define(wxSystemOptions_SetOption_2_1, 3478).
-define(wxSystemOptions_SetOption_2_0, 3479).
-define(wxAuiNotebookEvent_SetSelection, 3480).
-define(wxAuiNotebookEvent_GetSelection, 3481).
-define(wxAuiNotebookEvent_SetOldSelection, 3482).
-define(wxAuiNotebookEvent_GetOldSelection, 3483).
-define(wxAuiNotebookEvent_SetDragSource, 3484).
-define(wxAuiNotebookEvent_GetDragSource, 3485).
-define(wxAuiManagerEvent_SetManager, 3486).
-define(wxAuiManagerEvent_GetManager, 3487).
-define(wxAuiManagerEvent_SetPane, 3488).
-define(wxAuiManagerEvent_GetPane, 3489).
-define(wxAuiManagerEvent_SetButton, 3490).
-define(wxAuiManagerEvent_GetButton, 3491).
-define(wxAuiManagerEvent_SetDC, 3492).
-define(wxAuiManagerEvent_GetDC, 3493).
-define(wxAuiManagerEvent_Veto, 3494).
-define(wxAuiManagerEvent_GetVeto, 3495).
-define(wxAuiManagerEvent_SetCanVeto, 3496).
-define(wxAuiManagerEvent_CanVeto, 3497).
-define(wxLogNull_new, 3498).
-define(wxLogNull_destruct, 3499).
-define(wxTaskBarIcon_new, 3500).
-define(wxTaskBarIcon_destruct, 3501).
-define(wxTaskBarIcon_PopupMenu, 3502).
-define(wxTaskBarIcon_RemoveIcon, 3503).
-define(wxTaskBarIcon_SetIcon, 3504).
-define(wxLocale_new_0, 3505).
-define(wxLocale_new_2_0, 3506).
-define(wxLocale_new_2_1, 3507).
-define(wxLocale_destruct, 3508).
-define(wxLocale_Init_1, 3509).
-define(wxLocale_Init_2, 3510).
-define(wxLocale_AddCatalog_1, 3511).
-define(wxLocale_AddCatalog_2, 3512).
-define(wxLocale_AddCatalog_3, 3513).
-define(wxLocale_AddCatalogLookupPathPrefix, 3514).
-define(wxLocale_GetCanonicalName, 3515).
-define(wxLocale_GetLanguage, 3516).
-define(wxLocale_GetLanguageName, 3517).
-define(wxLocale_GetLocale, 3518).
-define(wxLocale_GetName, 3519).
-define(wxLocale_GetString_2, 3520).
-define(wxLocale_GetString_4, 3521).
-define(wxLocale_GetHeaderValue, 3522).
-define(wxLocale_GetSysName, 3523).
-define(wxLocale_GetSystemEncoding, 3524).
-define(wxLocale_GetSystemEncodingName, 3525).
-define(wxLocale_GetSystemLanguage, 3526).
-define(wxLocale_IsLoaded, 3527).
-define(wxLocale_IsOk, 3528).
-define(wxActivateEvent_GetActive, 3529).
-define(wxPopupWindow_new_0, 3530).
-define(wxPopupWindow_new_2, 3531).
-define(wxPopupWindow_Create, 3532).
-define(wxPopupWindow_Position, 3533).
-define(wxPopupWindow_destroy, 3534).
-define(wxPopupTransientWindow_new_0, 3535).
-define(wxPopupTransientWindow_new_2, 3536).
-define(wxPopupTransientWindow_Popup, 3537).
-define(wxPopupTransientWindow_Dismiss, 3538).
-define(wxPopupTransientWindow_destroy, 3539).
-define(wxOverlay_new, 3540).
-define(wxOverlay_destruct, 3541).
-define(wxOverlay_Reset, 3542).
-define(wxDCOverlay_new_6, 3543).
-define(wxDCOverlay_new_2, 3544).
-define(wxDCOverlay_destruct, 3545).
-define(wxDCOverlay_Clear, 3546).
-define(wxDropFilesEvent_GetPosition, 3547).
-define(wxDropFilesEvent_GetNumberOfFiles, 3548).
-define(wxDropFilesEvent_GetFiles, 3549).
-define(wxDisplay_new_0, 3550).
-define(wxDisplay_new_1_0, 3551).
-define(wxDisplay_new_1_1, 3552).
-define(wxDisplay_destruct, 3553).
-define(wxDisplay_IsOk, 3554).
-define(wxDisplay_GetClientArea, 3555).
-define(wxDisplay_GetGeometry, 3556).
-define(wxDisplay_GetName, 3557).
-define(wxDisplay_IsPrimary, 3558).
-define(wxDisplay_GetCount, 3559).
-define(wxDisplay_GetFromPoint, 3560).
-define(wxDisplay_GetFromWindow, 3561).
-define(wxDisplay_GetPPI, 3562).
-define(wxGCDC_new_1, 3563).
-define(wxGCDC_new_0, 3566).
-define(wxGCDC_destruct, 3567).
-define(wxGCDC_GetGraphicsContext, 3568).
-define(wxGCDC_SetGraphicsContext, 3569).
-define(wxNotificationMessage_new_0, 3570).
-define(wxNotificationMessage_new_2, 3571).
-define(wxNotificationMessage_destruct, 3572).
-define(wxNotificationMessage_AddAction, 3573).
-define(wxNotificationMessage_Close, 3574).
-define(wxNotificationMessage_SetFlags, 3575).
-define(wxNotificationMessage_SetIcon, 3576).
-define(wxNotificationMessage_SetMessage, 3577).
-define(wxNotificationMessage_SetParent, 3578).
-define(wxNotificationMessage_SetTitle, 3579).
-define(wxNotificationMessage_Show, 3580).
-define(wxNotificationMessage_UseTaskBarIcon, 3581).
-define(wxNotificationMessage_MSWUseToasts, 3582).
-define(wxWebView_New, 3584).
-define(wxWebView_GetCurrentTitle, 3585).
-define(wxWebView_GetCurrentURL, 3586).
-define(wxWebView_GetPageSource, 3587).
-define(wxWebView_GetPageText, 3588).
-define(wxWebView_IsBusy, 3589).
-define(wxWebView_IsEditable, 3590).
-define(wxWebView_LoadURL, 3591).
-define(wxWebView_Print, 3592).
-define(wxWebView_Reload, 3593).
-define(wxWebView_RunScript, 3594).
-define(wxWebView_SetEditable, 3595).
-define(wxWebView_SetPage, 3596).
-define(wxWebView_Stop, 3597).
-define(wxWebView_CanCopy, 3598).
-define(wxWebView_CanCut, 3599).
-define(wxWebView_CanPaste, 3600).
-define(wxWebView_Copy, 3601).
-define(wxWebView_Cut, 3602).
-define(wxWebView_Paste, 3603).
-define(wxWebView_EnableContextMenu, 3604).
-define(wxWebView_IsContextMenuEnabled, 3605).
-define(wxWebView_CanGoBack, 3606).
-define(wxWebView_CanGoForward, 3607).
-define(wxWebView_ClearHistory, 3608).
-define(wxWebView_EnableHistory, 3609).
-define(wxWebView_GoBack, 3610).
-define(wxWebView_GoForward, 3611).
-define(wxWebView_ClearSelection, 3612).
-define(wxWebView_DeleteSelection, 3613).
-define(wxWebView_GetSelectedSource, 3614).
-define(wxWebView_GetSelectedText, 3615).
-define(wxWebView_HasSelection, 3616).
-define(wxWebView_SelectAll, 3617).
-define(wxWebView_CanRedo, 3618).
-define(wxWebView_CanUndo, 3619).
-define(wxWebView_Redo, 3620).
-define(wxWebView_Undo, 3621).
-define(wxWebView_Find, 3622).
-define(wxWebView_CanSetZoomType, 3623).
-define(wxWebView_GetZoom, 3624).
-define(wxWebView_GetZoomType, 3625).
-define(wxWebView_SetZoom, 3626).
-define(wxWebView_SetZoomType, 3627).
-define(wxWebView_GetZoomFactor, 3628).
-define(wxWebView_SetZoomFactor, 3629).
-define(wxWebView_IsBackendAvailable, 3630).
-define(wxWebViewEvent_GetString, 3631).
-define(wxWebViewEvent_GetInt, 3632).
-define(wxWebViewEvent_GetTarget, 3633).
-define(wxWebViewEvent_GetURL, 3634).
